# Copyright (C) 2009, 2010, 2013, 2014 Nicira Networks, Inc.
#
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without warranty of any kind.
#
# If tests have to be skipped while building, specify the '--without check'
# option. For example:
# rpmbuild -bb --without check rhel/openvswitch-fedora.spec

# This defines the base package name's version.

%define pkgname openvswitch2.15


%if 0%{?commit:1}
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%endif

# Enable PIE, bz#955181
%global _hardened_build 1

# RHEL-7 doesn't define _rundir macro yet
# Fedora 15 onwards uses /run as _rundir
%if 0%{!?_rundir:1}
%define _rundir /run
%endif

# FIXME Test "STP - flush the fdb and mdb when topology changed" fails on s390x
# FIXME 2 tests fails on ppc64le. They will be hopefully fixed before official 2.11
%ifarch %{ix86} x86_64 aarch64
%bcond_without check
%else
%bcond_with check
%endif
# option to run kernel datapath tests, requires building as root!
%bcond_with check_datapath_kernel
# option to build with libcap-ng, needed for running OVS as regular user
%bcond_without libcapng
# option to build with ipsec support
%bcond_without ipsec

# Build python2 (that provides python) and python3 subpackages on Fedora
# Build only python3 (that provides python) subpackage on RHEL8
# Build only python subpackage on RHEL7
%if 0%{?rhel} > 7 || 0%{?fedora}
# On RHEL8 Sphinx is included in buildroot
%global external_sphinx 1
%else
# Don't use external sphinx (RHV doesn't have optional repositories enabled)
%global external_sphinx 0
%endif

Name: %{pkgname}
Summary: Open vSwitch
Group: System Environment/Daemons daemon/database/utilities
URL: http://www.openvswitch.org/
Version: 2.15.0
Release: 131%{?dist}

# Nearly all of openvswitch is ASL 2.0.  The bugtool is LGPLv2+, and the
# lib/sflow*.[ch] files are SISSL
# datapath/ is GPLv2 (although not built into any of the binary packages)
License: ASL 2.0 and LGPLv2+ and SISSL

%define dpdkver 20.11
%define dpdkdir dpdk
%define dpdksver %(echo %{dpdkver} | cut -d. -f-2)
# NOTE: DPDK does not currently build for s390x
# DPDK on aarch64 is not stable enough to be enabled in FDP
%if 0%{?rhel} > 7 || 0%{?fedora}
%define dpdkarches x86_64 ppc64le
%else
%define dpdkarches
%endif

%if 0%{?commit:1}
Source: https://github.com/openvswitch/ovs/archive/%{commit}.tar.gz#/openvswitch-%{commit}.tar.gz
%else
Source: https://github.com/openvswitch/ovs/archive/v%{version}.tar.gz#/openvswitch-%{version}.tar.gz
%endif
Source10: https://fast.dpdk.org/rel/dpdk-%{dpdkver}.tar.xz

%define docutilsver 0.12
%define pygmentsver 1.4
%define sphinxver   1.2.3
Source100: https://pypi.io/packages/source/d/docutils/docutils-%{docutilsver}.tar.gz
Source101: https://pypi.io/packages/source/P/Pygments/Pygments-%{pygmentsver}.tar.gz
Source102: https://pypi.io/packages/source/S/Sphinx/Sphinx-%{sphinxver}.tar.gz

Patch:     openvswitch-%{version}.patch

# The DPDK is designed to optimize througput of network traffic using, among
# other techniques, carefully crafted assembly instructions.  As such it
# needs extensive work to port it to other architectures.
ExclusiveArch: x86_64 aarch64 ppc64le s390x

# Do not enable this otherwise YUM will break on any upgrade.
# Provides: openvswitch
Conflicts: openvswitch < 2.15
Conflicts: openvswitch-dpdk < 2.15
Conflicts: openvswitch2.10
Conflicts: openvswitch2.11
Conflicts: openvswitch2.12
Conflicts: openvswitch2.13
Conflicts: openvswitch2.14

# FIXME Sphinx is used to generate some manpages, unfortunately, on RHEL, it's
# in the -optional repository and so we can't require it directly since RHV
# doesn't have the -optional repository enabled and so TPS fails
%if %{external_sphinx}
BuildRequires: python3-sphinx
%else
# Sphinx dependencies
BuildRequires: python-devel
BuildRequires: python-setuptools
#BuildRequires: python2-docutils
BuildRequires: python-jinja2
BuildRequires: python-nose
#BuildRequires: python2-pygments
# docutils dependencies
BuildRequires: python-imaging
# pygments dependencies
BuildRequires: python-nose
%endif

BuildRequires: gcc gcc-c++ make
BuildRequires: autoconf automake libtool
BuildRequires: systemd-units openssl openssl-devel
BuildRequires: python3-devel python3-setuptools
BuildRequires: desktop-file-utils
BuildRequires: groff-base graphviz
BuildRequires: unbound-devel
BuildRequires: systemtap-sdt-devel
# make check dependencies
BuildRequires: procps-ng
%if 0%{?rhel} > 7 || 0%{?fedora}
BuildRequires: python3-pyOpenSSL
%endif
%if %{with check_datapath_kernel}
BuildRequires: nmap-ncat
# would be useful but not available in RHEL or EPEL
#BuildRequires: pyftpdlib
%endif

%if %{with libcapng}
BuildRequires: libcap-ng libcap-ng-devel
%endif

%ifarch %{dpdkarches}
BuildRequires: meson
# DPDK driver dependencies
BuildRequires: zlib-devel numactl-devel
%ifarch x86_64
BuildRequires: rdma-core-devel >= 15 libmnl-devel
%endif

# Required by packaging policy for the bundled DPDK
Provides: bundled(dpdk) = %{dpdkver}
%endif

Requires: openssl iproute module-init-tools
#Upstream kernel commit 4f647e0a3c37b8d5086214128614a136064110c3
#Requires: kernel >= 3.15.0-0
Requires: openvswitch-selinux-extra-policy

Requires(pre): shadow-utils
Requires(post): /bin/sed
Requires(post): /usr/sbin/usermod
Requires(post): /usr/sbin/groupadd
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Obsoletes: openvswitch-controller <= 0:2.1.0-1

%description
Open vSwitch provides standard network bridging functions and
support for the OpenFlow protocol for remote per-flow control of
traffic.

%package -n python3-%{pkgname}
Summary: Open vSwitch python3 bindings
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Provides: python-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description -n python3-%{pkgname}
Python bindings for the Open vSwitch database

%package test
Summary: Open vSwitch testing utilities
License: ASL 2.0
BuildArch: noarch
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: tcpdump

%description test
Utilities that are useful to diagnose performance and connectivity
issues in Open vSwitch setup.

%package devel
Summary: Open vSwitch OpenFlow development package (library, headers)
License: ASL 2.0
Requires: %{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}

%description devel
This provides shared library, libopenswitch.so and the openvswitch header
files needed to build an external application.

%if 0%{?rhel} > 7 || 0%{?fedora} > 28
%package -n network-scripts-%{name}
Summary: Open vSwitch legacy network service support
License: ASL 2.0
Requires: network-scripts
Supplements: (%{name} and network-scripts)

%description -n network-scripts-%{name}
This provides the ifup and ifdown scripts for use with the legacy network
service.
%endif

%if %{with ipsec}
%package ipsec
Summary: Open vSwitch IPsec tunneling support
License: ASL 2.0
Requires: python3-%{pkgname} = %{?epoch:%{epoch}:}%{version}-%{release}
Requires: libreswan

%description ipsec
This package provides IPsec tunneling support for OVS tunnels.
%endif

%prep
%if 0%{?commit:1}
%setup -q -n ovs-%{commit} -a 10
%else
%setup -q -n ovs-%{version} -a 10
%endif
%if ! %{external_sphinx}
%if 0%{?commit:1}
%setup -n ovs-%{commit} -q -D -T -a 100 -a 101 -a 102
%else
%setup -n ovs-%{version} -q -D -T -a 100 -a 101 -a 102
%endif
%endif

mv dpdk-*/ %{dpdkdir}/

# FIXME should we propose a way to do that upstream?
sed -ri "/^subdir\('(usertools|app)'\)/d" %{dpdkdir}/meson.build

%patch -p1

%build
# Build Sphinx on RHEL
%if ! %{external_sphinx}
export PYTHONPATH="${PYTHONPATH:+$PYTHONPATH:}%{_builddir}/pytmp/lib/python"
for x in docutils-%{docutilsver} Pygments-%{pygmentsver} Sphinx-%{sphinxver}; do
    pushd "$x"
    python2 setup.py install --home %{_builddir}/pytmp
    popd
done

export PATH="$PATH:%{_builddir}/pytmp/bin"
%endif

./boot.sh

%ifarch %{dpdkarches}    # build dpdk
# Lets build DPDK first
cd %{dpdkdir}

ENABLED_DRIVERS=(
    bus/pci
    bus/vdev
    mempool/ring
    net/failsafe
    net/i40e
    net/ring
    net/vhost
    net/virtio
    net/tap
)

%ifarch x86_64
ENABLED_DRIVERS+=(
    bus/vmbus
    common/iavf
    common/mlx5
    net/bnxt
    net/enic
    net/iavf
    net/ice
    net/mlx4
    net/mlx5
    net/netvsc
    net/nfp
    net/qede
    net/vdev_netvsc
)
%endif

%ifarch aarch64 x86_64
ENABLED_DRIVERS+=(
    net/e1000
    net/ixgbe
)
%endif

# Since upstream doesn't have a way
for driver in drivers/*/*/; do
    driver=${driver#drivers/}
    driver=${driver%/}
    [[ " ${ENABLED_DRIVERS[@]} " == *" $driver "* ]] || \
        disable_drivers="${disable_drivers:+$disable_drivers,}"$driver
done

#CFLAGS="$(echo %{optflags} | sed -e 's:-Wall::g' -e 's:-march=[[:alnum:]]* ::g') -Wformat -fPIC %{_hardening_ldflags}" \
%set_build_flags
%__meson --prefix=%{_builddir}/dpdk-build \
         --buildtype=plain \
         -Ddisable_drivers="$disable_drivers" \
         -Dmachine=default \
         -Dmax_ethports=1024 \
         -Dmax_numa_nodes=8 \
         -Dtests=false \
         %{_vpath_builddir}
%meson_build
%__meson install -C %{_vpath_builddir} --no-rebuild

# FIXME currently with LTO enabled OVS tries to link with both static and shared libraries
rm -v %{_builddir}/dpdk-build/%{_lib}/*.so*

# Generate a list of supported drivers, its hard to tell otherwise.
cat << EOF > README.DPDK-PMDS
DPDK drivers included in this package:

EOF

for f in %{_builddir}/dpdk-build/%{_lib}/librte_net_*.a; do
    basename ${f} | cut -c12- | cut -d. -f1 | tr [:lower:] [:upper:]
done >> README.DPDK-PMDS

cat << EOF >> README.DPDK-PMDS

For further information about the drivers, see
http://dpdk.org/doc/guides-%{dpdksver}/nics/index.html
EOF

cd -
%endif    # build dpdk

# And now for OVS...
mkdir build-shared build-static
pushd build-shared
ln -s ../configure
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --disable-static \
        --enable-shared \
        --enable-ssl \
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes
make %{?_smp_mflags}
popd
pushd build-static
ln -s ../configure
%ifarch %{dpdkarches}
PKG_CONFIG_PATH=%{_builddir}/dpdk-build/%{_lib}/pkgconfig \
%endif
%configure \
%if %{with libcapng}
        --enable-libcapng \
%else
        --disable-libcapng \
%endif
        --enable-ssl \
%ifarch %{dpdkarches}
        --with-dpdk=static \
%endif
        --with-pkidir=%{_sharedstatedir}/openvswitch/pki \
        --enable-usdt-probes
make %{?_smp_mflags}
popd

/usr/bin/python3 build-aux/dpdkstrip.py \
        --dpdk \
        < rhel/usr_lib_systemd_system_ovs-vswitchd.service.in \
        > rhel/usr_lib_systemd_system_ovs-vswitchd.service

%install
rm -rf $RPM_BUILD_ROOT
make -C build-shared install-libLTLIBRARIES DESTDIR=$RPM_BUILD_ROOT
make -C build-static install DESTDIR=$RPM_BUILD_ROOT

install -d -m 0755 $RPM_BUILD_ROOT%{_rundir}/openvswitch
install -d -m 0750 $RPM_BUILD_ROOT%{_localstatedir}/log/openvswitch
install -d -m 0755 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch

install -p -D -m 0644 rhel/usr_lib_udev_rules.d_91-vfio.rules \
        $RPM_BUILD_ROOT%{_udevrulesdir}/91-vfio.rules

install -p -D -m 0644 \
        rhel/usr_share_openvswitch_scripts_systemd_sysconfig.template \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/openvswitch

for service in openvswitch ovsdb-server ovs-vswitchd \
               ovs-delete-transient-ports; do
        install -p -D -m 0644 \
                        rhel/usr_lib_systemd_system_${service}.service \
                        $RPM_BUILD_ROOT%{_unitdir}/${service}.service
done

%if %{with ipsec}
install -p -D -m 0644 rhel/usr_lib_systemd_system_openvswitch-ipsec.service \
                      $RPM_BUILD_ROOT%{_unitdir}/openvswitch-ipsec.service
%endif

install -m 0755 rhel/etc_init.d_openvswitch \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/openvswitch.init

install -p -D -m 0644 rhel/etc_openvswitch_default.conf \
        $RPM_BUILD_ROOT/%{_sysconfdir}/openvswitch/default.conf

install -p -D -m 0644 rhel/etc_logrotate.d_openvswitch \
        $RPM_BUILD_ROOT/%{_sysconfdir}/logrotate.d/openvswitch

install -m 0644 vswitchd/vswitch.ovsschema \
        $RPM_BUILD_ROOT/%{_datadir}/openvswitch/vswitch.ovsschema

install -d -m 0755 $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifdown-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
install -p -m 0755 rhel/etc_sysconfig_network-scripts_ifup-ovs \
        $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs

install -d -m 0755 $RPM_BUILD_ROOT%{python3_sitelib}
cp -a $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/ovstest \
        $RPM_BUILD_ROOT%{python3_sitelib}

# Build the JSON C extension for the Python lib (#1417738)
pushd python
(
export CPPFLAGS="-I ../include -I ../build-shared/include"
export LDFLAGS="%{__global_ldflags} -L $RPM_BUILD_ROOT%{_libdir}"
%py3_build
%py3_install
[ -f "$RPM_BUILD_ROOT/%{python3_sitearch}/ovs/_json$(python3-config --extension-suffix)" ]
)
popd

rm -rf $RPM_BUILD_ROOT/%{_datadir}/openvswitch/python/

install -d -m 0755 $RPM_BUILD_ROOT/%{_sharedstatedir}/openvswitch

install -d -m 0755 $RPM_BUILD_ROOT%{_prefix}/lib/firewalld/services/

install -p -D -m 0755 \
        rhel/usr_share_openvswitch_scripts_ovs-systemd-reload \
        $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovs-systemd-reload

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db
# The db needs special permission as IPsec Pre-shared keys are stored in it.
chmod 0640 $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/conf.db

touch $RPM_BUILD_ROOT%{_sysconfdir}/openvswitch/system-id.conf

# remove unpackaged files
rm -f $RPM_BUILD_ROOT/%{_bindir}/ovs-benchmark \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-docker \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-parse-backtrace \
        $RPM_BUILD_ROOT/%{_bindir}/ovs-testcontroller \
        $RPM_BUILD_ROOT/%{_sbindir}/ovs-vlan-bug-workaround \
        $RPM_BUILD_ROOT/%{_mandir}/man1/ovs-benchmark.1* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-testcontroller.* \
        $RPM_BUILD_ROOT/%{_mandir}/man8/ovs-vlan-bug-workaround.8*

%if ! %{with ipsec}
rm -f $RPM_BUILD_ROOT/%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%endif

# remove ovn unpackages files
rm -f $RPM_BUILD_ROOT%{_bindir}/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man1/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man5/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man7/ovn*
rm -f $RPM_BUILD_ROOT%{_mandir}/man8/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/ovn*
rm -f $RPM_BUILD_ROOT%{_datadir}/openvswitch/scripts/ovn*
rm -f $RPM_BUILD_ROOT%{_includedir}/ovn/*

%check
%if %{with check}
    pushd build-static
    touch resolv.conf
    export OVS_RESOLV_CONF=$(pwd)/resolv.conf
    if make check TESTSUITEFLAGS='%{_smp_mflags}' ||
       make check TESTSUITEFLAGS='--recheck'; then :;
    else
        cat tests/testsuite.log
        exit 1
    fi
    popd
%endif
%if %{with check_datapath_kernel}
    pushd build-static
    if make check-kernel RECHECK=yes; then :;
    else
        cat tests/system-kmod-testsuite.log
        exit 1
    fi
    popd
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%preun
%if 0%{?systemd_preun:1}
    %systemd_preun openvswitch.service
%else
    if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
        /bin/systemctl --no-reload disable openvswitch.service >/dev/null 2>&1 || :
        /bin/systemctl stop openvswitch.service >/dev/null 2>&1 || :
    fi
%endif

%pre
getent group openvswitch >/dev/null || groupadd -r openvswitch
getent passwd openvswitch >/dev/null || \
    useradd -r -g openvswitch -d / -s /sbin/nologin \
    -c "Open vSwitch Daemons" openvswitch

%ifarch %{dpdkarches}
    getent group hugetlbfs >/dev/null || groupadd hugetlbfs
    usermod -a -G hugetlbfs openvswitch
%endif
exit 0

%post
if [ $1 -eq 1 ]; then
    sed -i 's:^#OVS_USER_ID=:OVS_USER_ID=:' /etc/sysconfig/openvswitch

%ifarch %{dpdkarches}
    sed -i \
        's@OVS_USER_ID="openvswitch:openvswitch"@OVS_USER_ID="openvswitch:hugetlbfs"@'\
        /etc/sysconfig/openvswitch
%endif
fi
chown -R openvswitch:openvswitch /etc/openvswitch

%if 0%{?systemd_post:1}
    %systemd_post openvswitch.service
%else
    # Package install, not upgrade
    if [ $1 -eq 1 ]; then
        /bin/systemctl daemon-reload >dev/null || :
    fi
%endif

%postun
%if 0%{?systemd_postun:1}
    %systemd_postun openvswitch.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
%endif

%triggerun -- openvswitch < 2.5.0-22.git20160727%{?dist}
# old rpm versions restart the service in postun, but
# due to systemd some preparation is needed.
if systemctl is-active openvswitch >/dev/null 2>&1 ; then
    /usr/share/openvswitch/scripts/ovs-ctl stop >/dev/null 2>&1 || :
    systemctl daemon-reload >/dev/null 2>&1 || :
    systemctl stop openvswitch ovsdb-server ovs-vswitchd >/dev/null 2>&1 || :
    systemctl start openvswitch >/dev/null 2>&1 || :
fi
exit 0

%files -n python3-%{pkgname}
%{python3_sitearch}/ovs
%{python3_sitearch}/ovs-*.egg-info
%doc LICENSE

%files test
%{_bindir}/ovs-pcap
%{_bindir}/ovs-tcpdump
%{_bindir}/ovs-tcpundump
%{_mandir}/man1/ovs-pcap.1*
%{_mandir}/man8/ovs-tcpdump.8*
%{_mandir}/man1/ovs-tcpundump.1*
%{_bindir}/ovs-test
%{_bindir}/ovs-vlan-test
%{_bindir}/ovs-l3ping
%{_mandir}/man8/ovs-test.8*
%{_mandir}/man8/ovs-vlan-test.8*
%{_mandir}/man8/ovs-l3ping.8*
%{python3_sitelib}/ovstest

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/openvswitch/*
%{_includedir}/openflow/*
%exclude %{_libdir}/*.a
%exclude %{_libdir}/*.la

%if 0%{?rhel} > 7 || 0%{?fedora} > 28
%files -n network-scripts-%{name}
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif

%files
%defattr(-,openvswitch,openvswitch)
%dir %{_sysconfdir}/openvswitch
%{_sysconfdir}/openvswitch/default.conf
%config %ghost %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/conf.db
%ghost %attr(0600,-,-) %verify(not owner group md5 size mtime) %{_sysconfdir}/openvswitch/.conf.db.~lock~
%config %ghost %{_sysconfdir}/openvswitch/system-id.conf
%defattr(-,root,root)
%config(noreplace) %verify(not md5 size mtime) %{_sysconfdir}/sysconfig/openvswitch
%{_sysconfdir}/bash_completion.d/ovs-appctl-bashcomp.bash
%{_sysconfdir}/bash_completion.d/ovs-vsctl-bashcomp.bash
%config(noreplace) %{_sysconfdir}/logrotate.d/openvswitch
%{_unitdir}/openvswitch.service
%{_unitdir}/ovsdb-server.service
%{_unitdir}/ovs-vswitchd.service
%{_unitdir}/ovs-delete-transient-ports.service
%{_datadir}/openvswitch/scripts/openvswitch.init
%{_datadir}/openvswitch/scripts/ovs-check-dead-ifs
%{_datadir}/openvswitch/scripts/ovs-lib
%{_datadir}/openvswitch/scripts/ovs-save
%{_datadir}/openvswitch/scripts/ovs-vtep
%{_datadir}/openvswitch/scripts/ovs-ctl
%{_datadir}/openvswitch/scripts/ovs-kmod-ctl
%{_datadir}/openvswitch/scripts/ovs-systemd-reload
%config %{_datadir}/openvswitch/vswitch.ovsschema
%config %{_datadir}/openvswitch/vtep.ovsschema
%{_bindir}/ovs-appctl
%{_bindir}/ovs-dpctl
%{_bindir}/ovs-ofctl
%{_bindir}/ovs-vsctl
%{_bindir}/ovsdb-client
%{_bindir}/ovsdb-tool
%{_bindir}/ovs-pki
%{_bindir}/vtep-ctl
%{_libdir}/*.so.*
%{_sbindir}/ovs-vswitchd
%{_sbindir}/ovsdb-server
%{_mandir}/man1/ovsdb-client.1*
%{_mandir}/man1/ovsdb-server.1*
%{_mandir}/man1/ovsdb-tool.1*
%{_mandir}/man5/ovsdb.5*
%{_mandir}/man5/ovsdb-server.5.*
%{_mandir}/man5/ovs-vswitchd.conf.db.5*
%{_mandir}/man5/vtep.5*
%{_mandir}/man7/ovsdb-server.7*
%{_mandir}/man7/ovsdb.7*
%{_mandir}/man7/ovs-actions.7*
%{_mandir}/man7/ovs-fields.7*
%{_mandir}/man8/vtep-ctl.8*
%{_mandir}/man8/ovs-appctl.8*
%{_mandir}/man8/ovs-ctl.8*
%{_mandir}/man8/ovs-dpctl.8*
%{_mandir}/man8/ovs-kmod-ctl.8.*
%{_mandir}/man8/ovs-ofctl.8*
%{_mandir}/man8/ovs-pki.8*
%{_mandir}/man8/ovs-vsctl.8*
%{_mandir}/man8/ovs-vswitchd.8*
%{_mandir}/man8/ovs-parse-backtrace.8*
%{_udevrulesdir}/91-vfio.rules
%doc LICENSE NOTICE README.rst NEWS rhel/README.RHEL.rst
%ifarch %{dpdkarches}
%doc %{dpdkdir}/README.DPDK-PMDS
%attr(750,openvswitch,hugetlbfs) %verify(not owner group) /var/log/openvswitch
%else
%attr(750,openvswitch,openvswitch) %verify(not owner group) /var/log/openvswitch
%endif
/var/lib/openvswitch
%ghost %attr(755,root,root) %verify(not owner group) %{_rundir}/openvswitch
%{_datadir}/openvswitch/bugtool-plugins/
%{_datadir}/openvswitch/scripts/ovs-bugtool-*
%{_bindir}/ovs-dpctl-top
%{_sbindir}/ovs-bugtool
%{_mandir}/man8/ovs-dpctl-top.8*
%{_mandir}/man8/ovs-bugtool.8*
%if (0%{?rhel} && 0%{?rhel} <= 7) || (0%{?fedora} && 0%{?fedora} < 29)
%{_sysconfdir}/sysconfig/network-scripts/ifup-ovs
%{_sysconfdir}/sysconfig/network-scripts/ifdown-ovs
%endif

%if %{with ipsec}
%files ipsec
%{_datadir}/openvswitch/scripts/ovs-monitor-ipsec
%{_unitdir}/openvswitch-ipsec.service
%endif

%changelog
* Tue Jan 03 2023 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-131
- Merging upstream branch-2.15 [RH git: a985627824]
    Commit list:
    46b3a2c68d ci: Fix overriding OPTS provided from the yml.
    055a2a0f9d Prepare for 2.15.8.
    3f93cdff2b Set release date for 2.15.7.
    d61cbd9330 hash: Fix compilation error on Fedora 34 with GCC 11 and -O0.
    f24527c9b4 lldp: Fix bugs when parsing malformed AutoAttach.
    981ca96a55 rculist: Use rculist_back_protected to access prev.


* Tue Dec 06 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-130
- net/i40e: fix jumbo frame Rx with X722 [RH git: 1ec94aac1a]
    For NIC I40E_10G-10G_BASE_T_X722, when the port is configured with
    link speed, it cannot receive jumbo frame packets.
    
    Because it set maximum frame size failed when starts the port that
    the port link status is still down.
    
    This patch fix the error that starts the port will force set maximum
    frame size.
    
    Fixes: 2184f7cdeeaa ("net/i40e: fix max frame size config at port level")
    Cc: stable@dpdk.org
    
    Signed-off-by: Jie Wang <jie1x.wang@intel.com>
    Tested-by: Dukai Yuan <dukaix.yuan@intel.com>
    (cherry picked from commit 719469f13b11dbdc921b74258f2d10bd1c5328d4)


* Thu Nov 24 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-129
- Merging upstream branch-2.15 [RH git: 31a84993c7]
    Commit list:
    f4094a3d1d rculist: Fix iteration macros.
    262b62f1d3 learn: Fix parsing immediate value for a field match.
    408aac587c datapath-windows: Check the condition to reset pseudo header checksum on Rx side


* Sat Nov 05 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-128
- Merging upstream branch-2.15 [RH git: bd14504e2d]
    Commit list:
    41d86c94fa ci: Update meson requirement for DPDK.


* Wed Nov 02 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-127
- Merging upstream branch-2.15 [RH git: 96456c53d4]
    Commit list:
    bc49ebfbbd netdev-linux: Fix inability to apply QoS on ports with custom qdiscs. (#2138339)
    f1ae6e59bf vswitch.xml: Fix the name of rstp-path-cost option.
    b5539fe008 bond: Fix crash while logging not yet enabled member.


* Wed Oct 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-126
- Merging upstream branch-2.15 [RH git: 5ee74656ff]
    Commit list:
    5c1dc396fc unaligned: Correct the stats of packet_count and byte_count on Windows.
    b538282cd8 tests: Fix filtering of whole-second durations.


* Thu Oct 13 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-125
- Merging upstream branch-2.15 [RH git: f665a8bee1]
    Commit list:
    b0fac20b33 github: Update versions of action dependencies.


* Fri Oct 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-124
- Merging upstream branch-2.15 [RH git: a5332540ff]
    Commit list:
    af45645e13 Prepare for 2.15.7.
    9b2e802075 Set release date for 2.15.6.
    a8c92a2bbc daemon-unix: Fix file descriptor leak when monitor restarts child.
    917f72a4a8 vconn: Allow ECONNREFUSED in refuse connection test.


* Mon Oct 03 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-123
- Merging upstream branch-2.15 [RH git: 73cc21866f]
    Commit list:
    30b846ab1b dpdk: Use DPDK 20.11.6 release.


* Wed Sep 21 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-122
- vhost: fix virtqueue use after free on NUMA reallocation [RH git: ce74a8c364]
    [ upstream commit 0b2a2ca35037d6a5168f0832c11d9858b8ae946a ]
    
    translate_ring_addresses (via numa_realloc) may change a virtio device and
    virtio queue.
    The virtqueue object must be refreshed before accessing the lock.
    
    Fixes: 04c27cb673b9 ("vhost: fix unsafe vring addresses modifications")
    
    Signed-off-by: David Marchand <david.marchand@redhat.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Mon Sep 19 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-121
- Merging upstream branch-2.15 [RH git: 6af245093e]
    Commit list:
    fcc8774005 python: idl: Fix idl.Row.__str__ method.


* Mon Sep 19 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-120
- Merging upstream branch-2.15 [RH git: 64fdb5d43f]
    Commit list:
    60b1db0e22 bond: Avoid deadlock while updating post recirculation rules.
    fb46fd5643 ofproto-dpif-upcall: Add debug commands to pause/resume revalidators.
    88a936a57c test-list: Fix false-positive build failure with GCC 12.
    7461f82acc cirrus: Upgrade to FreeBSD 13.1 image.


* Tue Sep 06 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-119
- Merging 73655c64149 version: 20.11.6 [RH git: d8e8db8377]
    Commit list:
    73655c64149 version: 20.11.6
    ef311075d21 net/mlx5: fix Rx queue recovery mechanism
    089e01b375e vhost: fix header spanned across more than two descriptors
    8fff8520f35 vhost: discard too small descriptor chains
    28596f9ebca vhost: prevent async register
    ff7d483aaa6 ethdev: fix RSS update when RSS is disabled
    5a6aadbeec6 kni: fix build
    01609d56cb2 net/virtio-user: fix socket non-blocking mode
    c5dc4f6eb57 version: 20.11.6-rc1
    3e61bd97d9a doc: add more instructions for running as non-root
    aebfd0d7467 net/mlx5: fix MPRQ pool registration
    ca78fec981b net/hns3: support backplane media type
    9a7f5c16d0a net/mlx5: destroy indirect actions on port stop
    4a35f74c8a3 net/mlx5/linux: fix missed Rx packet stats
    153cef1fbf7 net/mlx5: handle MPRQ incompatibility with external buffers
    38f1f47db17 vdpa/mlx5: workaround var offset within page
    55942e4c4da vdpa/mlx5: fix maximum number of virtqs
    d702d0a0bd5 examples/link_status_interrupt: fix stats refresh rate
    20f57bfbd74 gro: fix identifying fragmented packets
    da29560252d service: fix lingering active status
    edc80cd334d net/igc: support multi-process
    dcf55291452 vhost: add some trailing newline in log messages
    ecb55969296 net/vhost: fix deadlock on vring state change
    e29fe1799c7 doc: fix readability in vhost guide
    9d474a9565a net/netvsc: fix vmbus device reference in multi-process
    04e6368ccdc app/testpmd: fix supported RSS offload display
    d3b24b9ea23 eventdev/eth_tx: fix queue delete
    e00e29a3ef4 doc: fix grammar and parameters in l2fwd-crypto guide
    d2384ccb959 doc: fix grammar and formatting in compressdev guide
    0e387937c4e crypto/qat: fix DOCSIS crash
    c24e3146091 examples/fips_validation: handle empty payload
    4985a6b0519 baseband/acc100: remove prefix of internal file
    85c979edf5e test/crypto: fix SNOW3G vector IV format
    c263e1d0476 test/crypto: fix ZUC vector IV format
    c2688091924 test/crypto: fix authentication IV for ZUC SGL
    21f394a60df net/bnxt: fix setting forced speed
    97229297562 net/bnxt: allow Tx only or Rx only
    71234d08d23 net/bnxt: fix switch domain allocation
    3f6c57b6a39 examples/distributor: fix distributor on Rx core
    a035314c1ed net/hns3: fix descriptors check with SVE
    4fef76f744c test: check memory allocation for CRC
    ef31c19b768 app/procinfo: show all non-owned ports
    67350d412d9 test/hash: fix out of bound access
    ed1bd718de3 rib: fix references for IPv6 implementation
    eb88adfe309 raw/ioat: fix build when ioat dmadev enabled
    40538d0b04c net/mlx5: fix stack buffer overflow in drop action
    f371572a767 net/mlx5: fix RSS expansion for patterns with ICMP item
    06375d5c71a net/mlx5: fix build with clang 14
    35ab757a023 net/qede: fix build with GCC 12
    d26e0087571 net/ice/base: fix build with GCC 12
    b9db1042c38 net/qede: fix build with GCC 13
    ac50182289f net/octeontx: fix port close
    c9f6c89d9aa ci: enable C++ check for Arm and PPC
    45eb4af4562 config: fix C++ cross compiler for Arm and PPC
    dbbdee4c12f malloc: fix allocation of almost hugepage size
    a0f0c7d9c51 vhost/crypto: fix descriptor processing
    8aa20e45c65 vhost/crypto: fix build with GCC 12
    338b9cbeb49 vhost: fix missing enqueue pseudo-header calculation
    bbba8ef0cd9 app/testpmd: revert MAC update in checksum forwarding
    9b4779bface net/txgbe: fix register polling
    50c6ddd6423 app/testpmd: fix bonding slave devices not released
    35768b682bc net/hns3: fix return value for unsupported tuple
    ecb5bc37dd3 net/hns3: remove duplicate definition
    5b5935a922e net/hns3: fix an unreasonable memset
    1adbdac76c2 test/bonding: fix RSS test when disable RSS
    da86d09eacf net/bonding: fix RSS inconsistency between ports
    a6ae86b161d eventdev/eth_tx: fix adapter creation
    b39e829bace test/ipsec: fix performance test
    8d49e2f6d19 test/crypto: fix cipher offset for ZUC
    cb03983da4a crypto/scheduler: fix queue pair in scheduler failover
    df7022dae82 test/ipsec: fix build with GCC 12
    5dbe3a6dad4 common/cpt: fix build with GCC 12
    0af3e2fef90 baseband/acc100: remove RTE prefix for internal macros
    437389abd91 baseband/acc100: add protection for some negative scenario
    34d98de156c baseband/acc100: update companion PF configure function
    10cdabfc105 eal/x86: drop export of internal alignment macro
    a6388c75952 trace: fix init with long file prefix
    3582b40156d app/flow-perf: fix build with GCC 12
    b089558de0e vdpa/ifc: fix build with GCC 12
    03197727fa5 net/ice: fix build with GCC 12
    cd10d48dcc5 net/mlx5: fix LRO validation in Rx setup
    c352cf12f32 app/testpmd: fix port status of bonding slave device
    93ca5fcf948 crypto/dpaa2_sec: fix crypto operation pointer
    40b12a05613 net/mlx5: fix RSS hash types adjustment
    145c5b453d8 net/bnxt: fix tunnel stateless offloads
    ee29f5fa6b1 vhost: fix async access
    c9a4ddc1e84 raw/ifpga: remove virtual devices on close
    3590f931372 kni: use dedicated function to set MAC address
    628b8d88c48 kni: use dedicated function to set random MAC address
    59d08006aa2 app/testpmd: fix multicast address pool leak
    9c1410c9b0a app/testpmd: fix packet segment allocation
    641e8b889ef doc: fix formatting and link in BPF library guide
    8f68d6fdc62 bus/fslmc: fix VFIO setup
    30c0b36a019 raw/ifpga: unregister interrupt on close
    14a27263310 examples/dma: fix Tx drop statistics
    6c17d926977 net/iavf: increase reset complete wait count
    4d11ba721d1 net/ice: fix outer L4 checksum in scalar Rx
    2d9b2c21900 doc: update matching versions in i40e guide
    789223ef41e net/iavf: fix Rx queue interrupt setting
    7ec8629367d net/iavf: fix mbuf release in multi-process
    755ea301dba net/iavf: fix queue start exception handling
    5b55b9b1ea7 net/i40e: fix max frame size config at port level
    d731c37a84e net/ice: fix MTU info for DCF
    e2660944da2 net/ice/base: fix getting sched node from ID type
    43eac062d11 net/ixgbe: add option for link up check on pin SDP3
    e0658c31961 net/iavf: fix data path selection
    133ec0ce1cf kni: fix build with Linux 5.18
    8048354bb7f net/mlx5: fix Tx recovery
    27dda79b5d2 examples/vhost: fix crash when no VMDq
    63005df100f vhost: fix deadlock when message handling failed
    4daae0ccb80 doc: fix vhost multi-queue reconnection
    ff874e673ad net/bnxt: fix compatibility with some old firmwares
    fa4da49c814 ethdev: fix port close in secondary process
    ac86ba961eb net/nfp: fix disabling VLAN stripping
    ef9b3014214 net/txgbe: fix max number of queues for SR-IOV
    d096c590dee ethdev: fix port state when stop
    89f54969e74 net/memif: fix overwriting of head segment
    711575cd7f7 net/bonding: fix mbuf fast free usage
    bdf2967cd5c app/testpmd: do not poll stopped queues
    f6060b16895 ethdev: prohibit polling stopped queue
    b4f13e0fdb0 app/testpmd: fix metering and policing command for RFC4115
    070f2b2b8a0 app/testpmd: replace hardcoded min mbuf number with macro
    fe09e56cb54 ethdev: fix possible null pointer access
    7386b532205 ethdev: fix memory leak in xstats telemetry
    7d17ff9a817 net/axgbe: fix xstats get return if xstats is null
    2b88b790c13 net/mvpp2: fix xstats get return if xstats is null
    007dfe41028 net/ipn3ke: fix xstats get return if xstats is null
    17467579f79 net/hns3: fix xstats get return if xstats is null
    eb7b05b5de5 ethdev: clarify null location case in xstats get
    cf28773c938 app/testpmd: remove useless pointer checks
    9463f695d7c app/testpmd: perform SW IP checksum for GRO/GSO packets
    3b918bc7112 doc: add missing auth algo for IPsec example
    5e4a008e4e1 drivers/crypto: fix warnings for OpenSSL version
    387d4b3ca78 test/crypto: fix null check for ZUC authentication
    b9b994dcf2d examples/ipsec-secgw: fix promiscuous mode option
    78059ea5a5f examples/ipsec-secgw: fix uninitialized memory access
    b4797829e77 devtools: fix null test for NUMA systems
    1d5a0d3379d doc: fix API index Markdown syntax
    de28f76399f mbuf: dump outer VLAN
    52822a9dd80 rib: fix traversal with /32 route
    3267a37602b acl: fix rules with 8-byte field size
    20ee31283df test: avoid hang if queues are full and Tx fails
    875e84259c1 eal/freebsd: fix use of newer cpuset macros
    8d8739b0829 test/ring: remove excessive inlining
    597718802f0 examples/l3fwd: fix scalar LPM
    705be731502 eal/x86: fix unaligned access for small memcpy
    ca4a019b457 net/bnxt: fix freeing VNIC filters
    03a539bf175 net/bnxt: recheck FW readiness if in reset process
    c105904aaa9 net/bnxt: fix link status when port is stopped
    f5cee4b2cac net/bnxt: force PHY update on certain configurations
    214e9d80bea net/bnxt: fix speed autonegotiation
    adb37db48f7 net/bnxt: avoid unnecessary endianness conversion
    167d0cbbfd5 net/bnxt: fix ring group on Rx restart
    c69db7f7f73 net/bnxt: fix Rx configuration
    7ded422e25a net/bnxt: fix device capability reporting
    ae5516cd7a3 net/bnxt: remove unused macro
    1dc7ed3e26a net/bnxt: fix reordering in NEON Rx
    472844ca06b app/testpmd: check statistics query before printing
    c72194a7543 net/hns3: remove unnecessary RSS switch
    21c2dd60110 net/hns3: remove redundant RSS tuple field
    7bce9bbfb89 net/hns3: fix rollback on RSS hash update
    9bf4eb4b1a3 net/hns3: fix RSS disable
    4997f02390d net/bonding: fix slave stop and remove on port close
    5f9aca077fd net/bonding: fix stopping non-active slaves
    d18ed4ab862 doc: update matching versions in ice guide
    ad18b9f42d7 net/dpaa: fix event queue detach
    6111eb8b88a vdpa/mlx5: fix dead loop when process interrupted
    e8971ff299a vdpa/mlx5: fix interrupt trash that leads to crash
    3763af6f3ee vhost: fix missing virtqueue lock protection
    45f14afcf9b net/vhost: fix TSO feature default disablement
    15d4339cfd9 net/virtio: restore some optimisations with AVX512
    e4729f10d06 net/vhost: fix access to freed memory
    730c2afc40b net/cxgbe: fix Tx queue stuck with mbuf chain coalescing
    063ce7b91c2 net/cxgbe: fix port ID in Rx mbuf
    5e7c16ee766 net/bonding: fix RSS key config with extended key length
    72144a630e4 net/nfp: remove unneeded header inclusion
    23bfe0031f9 test/hash: report non HTM numbers for single thread
    c29b05c2168 examples/l2fwd-crypto: fix stats refresh rate
    25165ac2415 common/dpaax: fix short MAC-I IV calculation for ZUC
    6b38d08f0c9 crypto/dpaa2_sec: fix operation status for simple FD
    45650937b46 crypto/dpaa_sec: fix secondary process probing
    faf1c3baa87 crypto/dpaa2_sec: fix buffer pool ID check
    2a680bbbc72 crypto/dpaa2_sec: fix fle buffer leak
    8856e5ecd7f crypto/dpaa_sec: fix digest size
    c1d1c4fdc32 eal: fix C++ include for device event and DMA
    ae1ed789dc3 mem: skip attaching external memory in secondary process
    072f7ee4708 test/table: fix buffer overflow on lpm entry
    c4d51b3f05b net/mlx5: fix Rx/Tx stats concurrency
    8a2529276af net/mlx5: fix GTP handling in header modify action
    e8995a25401 net/mlx5: fix Tx when inlining is impossible
    a61bd9df25d net/netvsc: fix calculation of checksums based on mbuf flag
    4d6996d25a3 net/i40e: populate error in flow director parser
    236835c94ff net/iavf: fix HW ring scan method selection
    faca6823330 examples/bond: fix invalid use of trylock
    9526e5c4a55 eal/windows: add missing C++ include guards
    5888f84ccdd eal/windows: fix data race when creating threads
    3a9281f20e3 crypto/ipsec_mb: fix GMAC parameters setting
    0fb580b1c01 crypto/ipsec_mb: fix length and offset settings
    abf68ccc8b1 version: 20.11.5
    5ae73012c8e dpaa2: fix build with RTE_LIBRTE_IEEE1588
    652658269f1 pmdinfogen: fix compilation with Clang 3.4.2 on CentOS 7
    9b390c4866d Revert "regexdev: fix section attribute of symbols"
    e0c907be841 net/cxgbe: remove useless address check
    576842a59ab version: 20.11.5-rc1
    fb2e2836bf3 cryptodev: add backward-compatible enum
    5cb14d74366 raw/ifpga: fix build with optimization
    c93d1201cc4 doc: fix missing note on UIO module in Linux guide
    5bc5bab0dc3 doc: replace characters for (R) symbol in Linux guide
    1d25333ce0a net/mlx5: fix port matching in sample flow rule
    6b92223d987 net/qede: fix Rx bulk mbuf allocation
    540401728f1 net/octeontx2: fix flow MCAM priority management
    975469beaa9 cryptodev: fix clang C++ include
    b16e4220e96 compressdev: fix missing space in log macro
    eca0c20f67d eal/freebsd: add missing C++ include guards
    dd8a8529443 examples/l3fwd: fix buffer overflow in Tx
    63f7788b203 app/testpmd: fix show RSS RETA on Windows
    6fc2a8d4995 bpf: fix build with some libpcap version on FreeBSD
    63f156544d2 net/mlx5: fix sample flow action on trusted device
    8c3269273e8 vhost: fix FD leak with inflight messages
    9bac6ad8620 vhost: fix queue number check when setting inflight FD
    cc761b30f00 net/mlx5: fix initial link status detection
    76cfc69e0e0 net/mlx5: fix link status change detection
    c885a4871f0 common/mlx5: add Netlink event helpers
    67cb024a793 raw/ifpga: fix interrupt handle allocation
    5500586d7bb examples/l3fwd: make Rx and Tx queue size configurable
    920e858767c examples/l3fwd: share queue size variables
    d4b61e1bc91 net/iavf: fix potential out-of-bounds access
    4c3ee244068 net/mlx5: fix MPLS/GRE Verbs spec ordering
    5beedd0836a net/mlx5: remove unused reference counter
    6979a661df1 net/mlx5: fix modify port action validation
    093fbd470b4 net/mlx5: fix NIC egress flow mismatch in switchdev mode
    42e5440e3f8 net/mlx5: fix shared RSS destroy
    cfcd67541cd net/mlx5: fix next protocol RSS expansion
    f26a66edd51 net/mlx5: fix inet IPIP protocol type
    5e425918296 net/bnxt: fix null dereference in session cleanup
    be45c834db6 ethdev: fix doxygen comments for device info struct
    64452c878f2 regexdev: fix section attribute of symbols
    2087ed6ae69 examples/kni: add missing trailing newline in log
    9b1f77b32c4 examples/flow_classify: fix failure message
    2ab2cfb2e87 examples/distributor: reduce Tx queue number to 1
    5a62d76f89c app/pdump: abort on multi-core capture limit
    40252a48762 raw/ifpga: fix monitor thread
    3e06257cf54 raw/ifpga: fix variable initialization in probing
    a7b346dd4d0 examples/vhost: fix launch with physical port
    76e812e3a50 net/ice: fix Tx offload path choice
    ee2cc7d3492 net/mlx5: fix matcher priority with ICMP or ICMPv6
    83781fe25a5 net/mlx5: fix GRE item translation in Verbs
    fa1579b29fa doc: fix typos and punctuation in flow API guide
    910925bc313 net/kni: fix config initialization
    fbc5f6b5fa7 net/txgbe: fix queue statistics mapping
    63030f8b7bf net/iavf: fix function pointer in multi-process
    f0a47837dd5 net/ixgbe: fix FSP check for X550EM devices
    38dee9e84ab net/hns3: increase time waiting for PF reset completion
    b27dbae232d net/hns3: fix VF RSS TC mode entry
    ff48dd55d6f net/hns3: fix RSS TC mode entry
    af3bd943eed net/hns3: remove duplicate macro definition
    52e0989cce1 compressdev: fix socket ID type
    6b75eeccec4 app/compress-perf: fix number of queue pairs to setup
    9df88bfefea app/compress-perf: fix socket ID type during init
    c30254b5da1 app/compress-perf: optimize operations pool allocation
    a166f7044b9 app/compress-perf: fix cycle count operations allocation
    e4ca3c9295b net/mlx5: workaround ASO memory region creation
    14849b1fa27 examples/qos_sched: fix compile failure
    eb0f31af87b net/mlx5: fix sibling device config check
    950554a680b common/octeontx2: update mailbox version to 0xb
    8d6bbbc514d kni: fix freeing order in device release
    3cb68884dd7 eal/linux: fix illegal memory access in uevent handler
    240dc513c2b distributor: fix potential overflow
    ffc6e4ea387 efd: fix uninitialized structure
    5cd3c071a3b test/efd: fix sockets mask size
    3fc564b2d0c app/testpmd: fix build without drivers
    2d1c255f300 net/i40e: fix unintentional integer overflow
    073988b8627 doc: correct name of BlueField-2 in mlx5 guide
    dc599f85f7f doc: replace broken links in mlx guides
    d07cbead1d1 doc: remove obsolete vector Tx explanations from mlx5 guide
    15f171576e7 common/mlx5: fix queue pair ack timeout configuration
    b94aa345475 net/ena: fix checksum flag for L4
    c73e88da707 net/ena: check memory BAR before initializing LLQ
    abbaa0b9d15 net/ena: fix meta descriptor DF flag setup
    5bb3ff7b47d net/ena: fix reset reason being overwritten
    b1d55a40d6c net/ena: skip timer if reset is triggered
    39f6adbf547 net/ena: remove unused offload variables
    d609358e180 net/ena: remove unused enumeration
    2c0325226cf net/txgbe: fix debug logs
    a274e8922f7 app/testpmd: fix GENEVE parsing in checksum mode
    8d5484e7a11 net/mlx5: fix ineffective metadata argument adjustment
    1b7f6d2ad92 net/i40e: enable maximum frame size at port level
    7eaca36d9c6 net/ice: fix overwriting of LSE bit by DCF
    b1b1cd71e95 net/af_xdp: ensure socket is deleted on Rx queue setup error
    92f88226d93 net/af_xdp: add missing trailing newline in logs
    33f2e375618 vhost: fix unsafe vring addresses modifications
    37936eb9ef2 vhost: fix field naming in guest page struct
    85ec94182b8 app/testpmd: check starting port is not in bonding
    f85bba14cc7 net/ixgbe: reset security context pointer on close
    3a4dd2649ff net/nfb: fix multicast/promiscuous mode switching
    aa27fa7968f net/nfb: fix array indexes in deinit functions
    92d7cb4446e crypto/ipsec_mb: fix ZUC operation overwrite
    4bc8222a12b crypto/ipsec_mb: fix ZUC authentication verify
    2eb55ed0243 crypto/virtio: fix out-of-bounds access
    dceebf9eebb baseband/acc100: avoid out-of-bounds access
    ced86386114 examples/l2fwd-crypto: fix port mask overflow
    9d1d70c9c8f doc: fix FIPS guide
    7b5609a5a0e cryptodev: fix RSA key type name
    a7aa7d8812a examples/qos_sched: fix core mask overflow
    b56b636c578 dma/idxd: configure maximum batch size to high value
    26bebaab555 ethdev: fix cast for C++ compatibility
    20baa98d62c vhost: add missing C++ guards
    581dea537e9 kni: add missing C++ guards
    9c5dd18e187 eventdev: add missing C++ guards
    f85ebc37b1d compressdev: add missing C++ guards
    4fd5a95b49c acl: add missing C++ guards
    8f9c5d8497f metrics: add missing C++ guards
    c840104e239 ethdev: add missing C++ guards
    f749277d082 telemetry: add missing C++ guards
    2c2d7d7af16 eal: add missing C++ guards
    5d76457095c eventdev/eth_tx: fix queue add error code
    40f28803d54 common/mlx5: fix error handling in multi-class probe
    e08edd8ac62 net/mlx5: fix memory socket selection in ASO management
    b6b775f2236 net/mlx5: fix MPRQ stride devargs adjustment
    0d9346a1153 net/mlx5: improve stride parameter names
    3adcf390138 common/mlx5: add minimum WQE size for striding RQ
    d8fadb1f7e2 net/nfp: free HW rings memzone on queue release
    8a78f023b7b config: add arch define for Arm
    c32be7490ed net/octeontx2:: fix base rule merge
    2bc455ec39e kni: update kernel API to set random MAC address
    105b5a41305 raw/ntb: clear all valid doorbell bits on init
    cf9be042906 crypto/dpaax_sec: fix auth/cipher xform chain checks
    bdd4b322cf9 compress/octeontx: fix null pointer dereference
    045d6f7c382 net/bnxt: fix ring calculation for representors
    c9eb38cd065 net/mlx5: fix inline length for multi-segment TSO
    c45f526d8a3 net/mlx5: fix committed bucket size
    64d94d1e8f5 net/ice: fix build with 16-byte Rx descriptor
    dc92390efe7 net/ice/base: add profile validation on switch filter
    da0833ea1f2 net/iavf: count continuous DD bits for Arm in flex Rx
    3152179d553 net/iavf: count continuous DD bits for Arm
    813b5994cfc net/sfc: demand Tx fast free offload on EF10 simple datapath
    964a78f4be1 net/sfc: do not push fast free offload to default TxQ config
    3915e71a30b net/memif: remove pointer deference before null check
    468cbff3fee vfio: cleanup the multiprocess sync handle
    184d1f7ae07 ipc: end multiprocess thread during cleanup
    b8e818df2ac test/mbuf: fix mbuf data content check
    32d2194f4f4 app/fib: fix division by zero
    1b84be5c004 mem: check allocation in dynamic hugepage init
    c7bd2f43549 vhost: fix C++ include
    b6dd9d6b2c8 table: fix C++ include
    97f298e3153 ipsec: fix C++ include
    04eb6cecc92 graph: fix C++ include
    48735e1e43e eventdev: fix C++ include
    ae0613e1333 eal: fix C++ include
    7cabaf23be3 stack: fix stubs header export
    c53cb87b513 regex/mlx5: fix memory allocation check
    0e63db20225 vhost: fix guest to host physical address mapping
    58767a90f4b app/testpmd: fix stack overflow for EEPROM display
    aea2c5be016 net/tap: fix to populate FDs in secondary process
    eea12b2874a ethdev: add internal function to device struct from name
    b040eaa3352 app/testpmd: fix bonding mode set
    c4a4ba788f6 net/bonding: fix reference count on mbufs
    78ee1995c90 net/bonding: fix promiscuous and allmulticast state
    8189e99b3a5 net/ixgbe: check filter init failure
    061f2416ab6 net/hns3: delete duplicated RSS type
    3f03bc5d20d net/hns3: fix operating queue when TCAM table is invalid
    b65114d8a35 net/hns3: fix insecure way to query MAC statistics
    73d42972448 net/hns3: fix RSS key with null
    edfefb90ca2 net/hns3: fix max packet size rollback in PF
    463673460a3 net/enic: fix dereference before null check
    cafb0cbdb4d eal/windows: remove useless C++ include guard
    e9734a61dac net/dpaa2: remove useless C++ include guard
    6506a4b4856 net/cxgbe: remove useless C++ include guard
    8650a0c17cb bus/dpaa: fix C++ include guard
    d3f8892862b test/mem: fix error check
    2da6c302476 eal/windows: fix error code for not supported API
    19746aaeabb ring: fix overflow in memory size calculation
    6e47aebf24d ring: fix error code when creating ring
    6c4c4398a43 ring: optimize corner case for enqueue/dequeue
    25f563d3887 doc: fix KNI PMD name typo
    1b61157ec94 kni: fix ioctl signature
    04a29bf8a81 build: remove deprecated Meson functions
    3215df7480e build: fix warning about using -Wextra flag
    14421740c49 build: fix warnings when running external commands
    29649b45905 doc: update matching versions in ice guide
    12eaf885f5d net/mlx5: reject jump to root table
    a133cd9add7 net/mlx5: fix mark enabling for Rx
    d8090fd8c4b net/virtio-user: check FD flags getting failure
    ac0c52244d8 net/virtio-user: fix resource leak on probing failure
    61144dff749 vdpa/ifc: fix log info mismatch
    9605f71afa8 net/virtio: fix Tx queue 0 overriden by queue 128
    16ba91d4f3c vdpa/mlx5: workaround queue stop with traffic
    f3cd5320d89 net/hns3: fix using enum as boolean
    90ada5e388b net/bonding: fix RSS with early configure
    1ed391676f5 net/memif: remove unnecessary Rx interrupt stub
    10445169472 raw/ifpga/base: fix port feature ID
    edea3f39ddc net/bnxt: fix VF resource allocation strategy
    3e0a066400a net/bnxt: fix memzone allocation per VNIC
    7ee6d43e5e5 net/bnxt: handle ring cleanup in case of error
    e7f6c7629a4 net/bnxt: fix check for autoneg enablement
    f05952e7bfe raw/ifpga: fix thread closing
    ab9cde2e723 net/ice: fix link up when starting device
    06665489e6c raw/ifpga/base: fix SPI transaction
    ff474dde7be net/sfc: validate queue span when parsing flow action RSS
    238f205dd5c net/nfp: remove useless range checks
    e977e8ef8e6 net/nfp: remove duplicated check when setting MAC address
    f06710409fe net/mlx5: fix maximum packet headers size for TSO
    1d10966a22c net/dpaa2: fix timestamping for IEEE1588
    bab9d520cbd net/dpaa2: fix unregistering interrupt handler
    b5b90b6ea32 net/cxgbe: fix dangling pointer by mailbox access rework
    a5f8244a5f8 app/testpmd: fix external buffer allocation
    a2f86fa32fc app/testpmd: fix dereference before null check
    239f57b000c net/bonding: fix mode type mismatch
    8b6401daed4 net/af_xdp: fix build with -Wunused-function
    a5018b1aa63 net/axgbe: use PCI root complex device to distinguish device
    a26506bce10 app/testpmd: fix Tx scheduling interval
    8d0afb3f689 net/bonding: fix offloading configuration
    e93a5f44791 net/bnxt: check VF representor pointer before access
    31080d4c621 net/bnxt: fix xstats query
    52d79e82448 net/bnxt: fix PAM4 mask setting
    766d7701ba0 net/bnxt: fix handling of VF configuration change
    ef80ca417e1 net/bnxt: get maximum supported multicast filters count
    893c784eef7 net/bnxt: add null check for mark table
    5889a245444 net/bnxt: cap maximum number of unicast MAC addresses
    fa8cc81989e net/bnxt: fix restoring VLAN filtering after recovery
    7275db81e80 net/bnxt: restore RSS configuration after reset recovery
    c612a4bbf3a net/bnxt: fix queue stop operation
    3ea46b608a0 net/bnxt: fix multicast MAC restore during reset recovery
    5ee96222abf net/bnxt: fix multicast address set
    e2c9b9902d3 net/bnxt: fix xstats names query overrun
    66aa6f94671 net/mlx5: relax headroom assertion
    0374774e882 net/mlx5: fix GRE protocol type translation for Verbs
    a5edf851758 net/mlx5: fix RSS expansion with explicit next protocol
    1c64873e8d9 net/mlx5: fix assertion on flags set in packet mbuf
    24e61aa014c net/ixgbe: add vector Rx parameter check
    a02fbcde752 net/ice: fix Tx checksum offload
    8577641fca0 net/ice: track DCF state of PF
    f7b02e11272 net/ice: fix Tx checksum offload capability
    793c8206207 net/qede: fix redundant condition in debug code
    4ee719c72ea devtools: fix comment detection in forbidden token check
    33a5d155d0d examples/ipsec-secgw: fix default flow rule creation
    dff4380aaeb examples/ipsec-secgw: fix eventdev start sequence
    19524c9cb13 examples/l3fwd: fix Rx burst size for event mode
    6bfaf85e5bc doc: fix dlb2 guide
    eb5a21b54a5 eal/linux: log hugepage create errors with filename
    0602aa0fd4c dma/idxd: fix paths to driver sysfs directory
    4548934a6d3 bus/ifpga: remove useless check while browsing devices
    7c66f7f6796 doc: remove dependency on findutils on FreeBSD
    cf1a7f66a96 maintainers: update for stable branches
    269489433cd doc: replace deprecated distutils version parsing
    0b5a6c7b32c fix spelling in comments and strings
    b05d183a7f6 config/ppc: fix build with GCC >= 10
    4d47f374314 version: 20.11.4
    ebdc786158c common/qat: revert fix queut pairs number
    35fb9c4b938 build: disable Windows warnings for insecure funtions
    395bb64d1b5 kni: fix build for SLES15-SP3
    c3e1d196e53 table: fix missing headers on ARM64
    04d8f7c4968 eal/common: exclude code unsupported on Windows
    bab4318634e version: 20.11.4-rc1
    16fd24c265a raw/octeontx2_ep: remove unused variable
    66b0d3a2f4f net/mlx5: fix flow shared age action reference counting
    930ac3db1a3 crypto/octeontx2: fix lookaside IPsec IPv6
    67992959ee1 baseband/acc100: fix 4GUL outbound size
    86cbc9786f1 net/mlx5: fix RSS expansion with EtherType
    460136f414f net/mlx5: fix RSS expansion for L2/L3 VXLAN
    fa62ff901fa net/mlx5: fix RSS expansion traversal over next nodes
    8ab211780c9 net/mlx5: fix RSS expansion for explicit graph node
    519154bdd5d net/mlx5: fix RSS expansion for inner tunnel VLAN
    d94b4674356 doc: fix a typo in EAL guide
    ab2ec45d52e net/mlx5: fix devargs validation for multi-class probing
    368163da050 doc: fix typo in coding style
    951ab7b6080 doc: capitalise PMD
    cea3552ab7a fix PMD wording
    ed9a13b0fa8 remove repeated 'the' in the code
    769cd1d909d net/mlx5: fix GENEVE and VXLAN-GPE flow item matching
    62f37b7a5bf net/mlx5: fix GRE flow item matching
    22dc2d42b2b app/testpmd: fix hexadecimal parser with odd length
    585669bf46a doc: fix memif driver acronyms
    fed3abcad0a net/memif: allow stopping and closing device
    f489ca40fb0 net/mlx5: fix multi-segment packet wraparound
    14f47af82f2 net/mlx5: fix flow mark with sampling and metering
    03f92022bbd net/mlx4: fix empty Ethernet spec with VLAN
    acf010a8e5d net/mlx5: fix metadata and meter split shared tag
    f803c82df76 net/bnxt: fix autoneg on PAM4 links
    401a4bc91e6 doc: remove repeated repeated words
    62b23da8166 examples/ptpclient: fix delay request message
    e8e74b58046 doc: strip build artefacts for examples file list
    47e5dbb3a6b mbuf: fix dump of dynamic fields and flags
    07ab7b7d9ab kni: restrict bifurcated device support
    1f3b7af315e drivers/crypto: fix IPsec TTL decrement option
    2aa2b0f1e5c crypto/ipsec_mb: fix cipher key setting
    7695cdb5e22 common/mlx5: fix user mode register access attribute
    5045cabbec3 net/mlx5: fix MPLS tunnel outer layer overwrite
    c897e773f9b net/mlx5: fix partial inline of fine grain packets
    81836e2c897 app/testpmd: fix tunnel offload validation
    47c838de7cb net/failsafe: fix secondary process probe
    14bb775f70f net/bnxt: fix Rx next consumer index in mbuf alloc fail
    b0ecc5765f3 net/mlx5: fix mutex unlock in Tx packet pacing cleanup
    820f9547884 net/hns3: optimize Tx performance by mbuf fast free
    e628b925e55 net/mlx5: fix GRE protocol type translation
    b831cc80b25 net/mlx5: fix GENEVE protocol type translation
    8708f00342e net/mlx5: fix RSS expansion scheme for GRE header
    3d4d2600f35 net/mlx5: add Ethernet header to GENEVE RSS expansion
    5b82df45c1d net/mlx5: fix VXLAN-GPE next protocol translation
    01029bb978c vdpa/mlx5: fix mkey creation check
    0da7f8f9f26 doc: fix Doxygen examples build on FreeBSD
    d3a4e55ca18 app/flow-perf: fix parsing of invalid option
    9827b33ea14 examples/ntb: fix build dependency
    e8a8503d426 config/x86: skip GNU binutils bug check for LLVM
    07e1e6e7989 fix spelling in comments and doxygen
    19678781819 examples/multi_process: fix Rx packets distribution
    75af4401a45 examples/l3fwd-power: fix early shutdown
    3a8dc3e8dcd test/crypto: remove unnecessary stats retrieval
    cd50e6f4381 common/cpt: fix KASUMI input length
    bc4695a1381 test/crypto: fix missing return checks
    fa912be2c53 test/crypto: fix data lengths
    139df458858 test/crypto: skip plain text compare for null cipher
    985e9324d96 event/dlb2: fix delayed pop test in selftest
    4f17d46380f eventdev/eth_tx: fix queue delete logic
    0d266c9fe9d examples/performance-thread: remove unused hits count
    9a514a21d82 test/distributor: remove unused counter
    7db7d2e658f net/vmxnet3: fix build with clang 13
    0c8aa412492 net/qede/base: remove unused message size
    e72e4962d5e net/nfp: remove unused message length
    6fdb54e73f8 net/liquidio: remove unused counter
    415c636992b net/bnxt: remove some unused variables
    ae0fe7d7996 event/sw: remove unused inflight events count
    22ebe5378e9 bus/fslmc: remove unused device count
    14e420ac852 net/octeontx: remove unused packet length
    0a475878ef6 net/hinic/base: remove some unused variables
    878f71050ea test/red: fix typo in test description
    0ed3a7333f7 ethdev: fix typos
    5d3a7aab196 app/testpmd: fix DCB in VT configuration
    40588e9f6f1 net/mlx5: fix Tx scheduling check
    712ace31c57 net/iavf: fix pointer of meta data
    2f5b7df1e4c net/i40e: fix risk in descriptor read in scalar Rx
    fdb91c91e80 doc: describe timestamp limitations for mlx5
    7ae03fc171b common/mlx5: fix build for zero-length headroom array
    6d132c0f732 net/mlx5: fix RETA update without stopping device
    2a9a0c9d63e net/mlx5: fix tag ID conflict with sample action
    5744208d623 net/mlx5: fix tunnel offload validation
    180fa49727d power: fix build with clang 13
    3088dda4694 net/mlx5: workaround MR creation for flow counter
    2e7f6f9336f vdpa/mlx5: workaround guest MR registrations
    4f691f2c970 vdpa/mlx5: workaround dirty bitmap MR creation
    6108eff3be1 common/mlx5: create wrapped MR
    2991d7abc22 common/mlx5: glue MR registration with IOVA
    dfae8dc0ec8 net/virtio: fix Tx checksum for tunnel packets
    5de5f15c5b0 net/bnxt: fix VLAN indication in Rx mbuf
    8ef3bed3880 net/mlx5: do not close stdin on error
    b99528eb2d5 net/nfp: cancel delayed LSC work in port close logic
    463cd893e2a net/af_packet: fix ignoring full ring on Tx
    ce48d011679 net/ixgbe: fix port initialization if MTU config fails
    6c0517f5295 net/iavf: fix multi-process shared data
    1d5d3847af7 net/hns3: fix interrupt vector freeing
    5ff9c28131e net/hns3: fix residual MAC after setting default MAC
    dbf27ac1e7c net/i40e: fix i40evf device initialization
    89a78fde25d app/testpmd: remove unused header file
    4fd42c0a44f net/hns3: simplify queue DMA address arithmetic
    480eecce545 interrupt: fix request notifier interrupt processing
    e963a3650be vfio: set errno on unsupported OS
    1fd63293649 vfio: fix FreeBSD documentation
    07e02c596a3 vfio: fix FreeBSD clear group stub
    d2a21b149a9 kni: check error code of allmulticast mode switch
    e5f58ae926b net/mlx5: remove duplicated reference of Tx doorbell
    19c487a7cdb common/mlx5: fix UAR allocation diagnostics messages
    f368f1bbb5e common/mlx5: remove unreachable branch in UAR allocation
    87e20726cc6 app/testpmd: remove double dependency on bitrate lib
    3be19a63d4f common/sfc_efx: fix debug compilation control
    ac08c1ba97f ethdev: fix crash on owner delete
    5ec9795c686 net/i40e: fix forward outer IPv6 VXLAN
    b2d0ed96d5e net/mlx5: fix Rx queue memory allocation return value
    63ba41d7ee1 net/mlx5: fix Altivec Rx
    6385edbe1c9 common/mlx5: fix flex parser DevX creation routine
    2f2c2b5b7e7 common/qat: fix queue pairs number
    b332923763a examples/ipsec-secgw: move global array from header
    01f69bbd741 test/compress-perf: remove unused variable
    c10c8edfa49 examples/fips_validation: fix device start
    13dc08c1cad crypto/qat: fix uncleared cookies after operation
    7bacbc5eb3b crypto/qat: fix status in RSA decryption
    9120474fcc0 test/crypto: fix max length for raw data path
    d5b7c084fc3 net/txgbe: fix packet statistics
    9e127ea9699 net/hns3: unregister MP action on close for secondary
    5bf8d5b2f7b net/hns3: fix multi-process action register and unregister
    69212ae06b3 net/hns3: fix secondary process reference count
    9488e784fc6 net/ice: fix flow redirect
    e3632cfa140 net/ice: save rule on switch filter creation
    4c5c31b120f net/enic: avoid error message when no advanced filtering
    5927fdf1541 net/bnxt: fix firmware version query
    6b4e43eaaa7 net/i40e: fix 32-bit build
    8d4494154ef net/hns3: fix mailbox communication with HW
    c4d20e838ee net/virtio: fix link update in speed feature
    1c5f0499f59 net/mlx5: fix RSS RETA update
    223d61646c4 app/testpmd: fix RSS type display
    6a4ec07e263 app/testpmd: fix RSS key length
    a5e35344817 doc: update NIC feature matrix for bnxt
    e4082697ba3 net/iavf: fix shared data in multi-process
    0e28edc58ae net/ice: fix function pointer in multi-process
    8c4227ddae4 mem: fix dynamic hugepage mapping in container
    e324ec6bc4c malloc: fix allocation with unknown socket ID
    394952356af eal/linux: fix uevent message parsing
    558953d965a eal/linux: remove unused variable for socket memory
    2af8cf0baea eal: fix device iterator when no bus is selected
    d2f33a2cbed test/mbuf: fix access to freed memory
    d43921f4afd test/cmdline: fix memory leak
    7cc4ec4aba8 eal/freebsd: fix IOVA mode selection
    e306e6d9b37 test: fix ring PMD initialisation
    d6f5ee89044 net/i40evf: extend the polling times of vf reset
    6b334554114 net/i40e: fix buffer size alignment
    982e2c63d11 common/mlx5: fix physical port name recognition
    e567087a438 eal/windows: fix IOVA mode detection and handling
    4272080bb1b rib: fix IPv6 depth mask
    9902d7dcb9e lpm6: fix buffer overflow
    1729b2c3376 hash: fix Doxygen comment of Toeplitz file
    f1b1f1186a0 eal: reset lcore task callback and argument
    0cab294bc0f eal/x86: avoid cast-align warning in memcpy functions
    b91dcac7117 mbuf: avoid cast-align warning in data offset macro
    11895408d95 net: avoid cast-align warning in VLAN insert function
    0f1d36a7460 doc: fix default mempool option in guides
    d60f7f0105d usertools/pmdinfo: fix plugin auto scan
    a0347e7e7e6 pipeline: fix instruction label check
    ff1898349e7 test/event: fix timer adapter creation test
    1057ce433cd app/testpmd: fix packet burst spreading stats
    3d0f0036323 ethdev: fix PCI device release in secondary process
    e880b1c1638 net/virtio: fix avail descriptor ID
    04bd8e7fcbd net/virtio: fix indirect descriptor reconnection
    abd207e5fa4 vhost: add sanity check on inflight last index
    2074d205616 vdpa/mlx5: retry VAR allocation during vDPA restart
    3713e9c3703 vdpa/mlx5: workaround FW first completion in start
    d8ce32c71e8 net/virtio: fix check scatter on all Rx queues
    136944a2cb7 net/mlx5: close tools socket with last device
    8ce5c675a82 net/mlx5: fix Rx queue resource cleanup
    829fbd72525 devtools: fix letter case check in commit title
    74fb264b051 bpf: allow self-xor operation
    edb5fcae312 eventdev/eth_rx: fix WRR buffer overrun
    f7fa666eec6 app/eventdev: fix terminal colour after control-c exit
    d95c7a669d0 mbuf: fix reset on mbuf free
    2eb840f1aec test/hash: fix buffer overflow with jhash
    869a35948ef ethdev: forbid closing started device
    c95ffe56718 net/i40e: fix risk in descriptor read in NEON Rx
    dd5334c4acb net/ice: fix generic build on FreeBSD
    6e46115943b net/mlx5: support more tunnel types
    8a28600abc5 app/testpmd: add tunnel types
    73250dca43d app/testpmd: fix access to DSCP table entries
    5d3a5129947 net/ena: advertise scattered Rx capability
    84a35ce3086 net/ena: fix per-queue offload capabilities
    d1ccc7019d1 net/ena: fix offload capabilities verification
    ac9f3ffd5d9 net: fix aliasing in checksum computation
    44cd82b5198 doc: fix emulated device names in e1000 guide
    6d32420ce90 net/ice: fix deadlock on flow redirect
    137ea50f604 drivers/net: remove queue xstats auto-fill flag
    d19e3bea520 net/txgbe: fix to get interrupt status
    349ac4cf40d app/testpmd: fix hex string parser in flow commands
    1edd186c4fc net/softnic: fix useless address check
    2dcdba115e0 net/enic: fix filter mode detection
    8cb630d9e49 net/mlx5: fix tunneling support query
    15242b3f602 net/mlx5: fix software parsing support query
    7379aa7aa8d net/i40e/base: fix using checksum before check
    610b598aa0c net/i40e/base: fix potentially uninitialized variables
    c1977a22f6a net/i40e/base: fix function name in comments
    a02cb9ff216 net/i40e/base: fix AOC media type
    abc841874fe net/i40e/base: fix update link data for X722
    7dcf2e3db48 net/i40e/base: fix PF reset
    37817b554a9 net/i40e/base: fix PHY identifiers for 2.5G and 5G adapters
    63e0206bdb1 net/ixgbe: fix queue release
    e69e21048d4 net/i40e: fix Rx packet statistics
    ce17996fc6e net/sfc: update comment about representor support
    f74eaa58691 net/sfc: free MAE lock once switch domain is assigned
    b391213ff81 app/testpmd: retain all original dev conf when config DCB
    710a47c4c63 net/bonding: fix RSS key length
    e0d9039f2ed net/bonding: fix dedicated queue mode in vector burst
    e788cc2006e app/testpmd: fix txonly forwarding
    4a2204af7bf app/testpmd: update forward engine beginning
    4370d53fb55 net/af_xdp: disable secondary process support
    6ec9dcdfed4 test/bpf: fix undefined behavior with clang
    939685eaec9 cryptodev: fix multi-segment raw vector processing
    ca9b74af257 app/crypto-perf: fix AAD template copy overrun
    386085df051 mempool: deprecate unused physical page defines
    3446f6d2008 mbuf: enforce no option for dynamic fields and flags
    a8590be3636 test/atomic: fix 128-bit atomic test with many cores
    2bd66f32c91 mbuf: fix typo in comment
    aa4a2ef3fee telemetry: fix JSON output buffer length
    341804051a4 eal/freebsd: ignore in-memory option
    be9717a4ccb bus/vmbus: fix ring buffer mapping in secondary process
    c41706bb6e7 eal/x86: fix some CPU extended features definitions
    cc7ded572d9 test/service: fix race in attr check
    3ee89708230 test/service: fix some comment
    cd24395f653 test/event_crypto: fix event crypto metadata write
    de983dfa6d9 examples/fips_validation: fix resetting pointer
    1aab8371d34 examples/fips_validation: remove unused allocation
    6d4f5a16392 eal/windows: do not install virt2phys header
    822f885986d eal/windows: fix CPU cores counting
    449612955b7 net: fix checksum API documentation
    288a450bb90 net/hns3: fix input parameters of MAC functions
    2adcdc8cc79 net/ixgbe: fix memzone leak on queue re-configure
    4e60a455598 net/i40e: fix memzone leak on queue re-configure
    8b56d276440 net/ice: fix memzone leak on queue re-configure
    b51d3a49704 net/e1000: fix memzone leak on queue re-configure
    8f825b3b132 ethdev: fix xstats by ID API documentation
    b4108eb62c3 common/dpaax: fix physical address conversion
    a7bb99fc860 raw/ifpga/base: fix linking with librt
    1b8fac0312d test/latency: fix loop boundary
    a00d38a2e16 bus/vmbus: fix leak on device scan
    3df90648847 net/mlx5: fix flow tables double release
    95cf6a360f5 net/bnxt: fix tunnel port accounting
    5b3f9bec58a net/bnxt: fix memzone free for Tx and Rx rings
    f1c89a7eddc net/bnxt: fix Tx queue startup state
    ea39d70a508 net/bnxt: fix function driver register/unregister
    c9eddf61f5d net/ice: retry getting VF VSI map after failure
    90d7fd5b10e common/iavf: fix ARQ resource leak
    eca9795521b net/iavf: fix Rx queue IRQ resource leak
    cd90c7a5b2e net/ice: fix double free ACL flow entry
    1900a185181 net/iavf: fix high CPU usage on frequent command
    49a2b0ca693 net/virtio: do not use PMD log type
    758eb05f2b5 net/virtio: fix Tx completed mbuf leak on device stop
    0da178c94e7 net/virtio: fix Tx cleanup functions to have same signature
    9786a89ed40 vhost: clean IOTLB cache on vring stop
    192d2f2dcd4 test/mem: fix memory autotests on FreeBSD
    95934ebba9b eal/freebsd: lock memory device to prevent conflicts
    ad4051ca8f5 usertools: fix handling EOF for telemetry input pipe
    45f9d14e11c bitrate: fix calculation to match API description
    102d6df14d5 bitrate: fix registration to match API description
    1e697abcfd9 ring: fix Doxygen comment of internal function
    51a9cd2327f eal: remove Windows-specific list of common files
    8a43d7c5f43 eal/windows: export version function
    196cda0e31b bus/pci: fix unknown NUMA node value on Windows
    7b3cdb7c649 kvargs: fix comments style
    edfd68842c4 net/memif: fix chained mbuf determination
    39f117c3b5e net/mlx5: fix shared RSS destruction
    5d3374aff1b net/mlx5: fix memory leak on context allocation failure
    4649ead943c net/octeontx: fix access to indirect buffers
    474bbafd6f2 net/iavf: fix mbuf leak
    60974c7c2c2 net/ice/base: calculate logical PF ID
    8532dae4d66 net/bonding: fix memory leak on closing device
    25533b38a69 test/compress: fix buffer overflow
    8f07dfbc181 examples/ipsec-secgw: fix parsing of flow queue
    e78d085e36d stack: fix reload head when pop fails
    6f7c9fde717 vdpa/mlx5: fix large VM memory region registration
    bb7f3bc24ba sched: get 64-bit greatest common divisor
    2a5a4216585 bus/pci: fix unknown NUMA node value on Windows
    d593c0569e9 doc: fix numbers power of 2 in LPM6 guide
    88719f1273a net/iavf: fix Rx queue buffer size alignment
    64734ba6e23 net/i40e/base: fix resource leakage
    012f9cfceb4 net/iavf: fix mbuf leak
    af659df64ec net/ice/base: fix PF ID for DCF
    4fc96ab6c9d net/i40e: fix device startup resource release
    30fcdc4f505 net/i40e: fix mbuf leak
    c7afc998044 net/octeontx2: fix MTU when PTP is enabled
    92569f9804d net/virtio: fix device configure without jumbo Rx offload
    aafb232afb5 vhost: log socket path on adding connection
    e0d08d0c032 net/virtio: fix repeated freeing of virtqueue
    e543f89ba58 vhost: fix crash on port deletion
    dd6e6e33c7c net/virtio-user: fix Rx interrupts with multi-queue
    b00b073569d net/virtio: avoid unneeded link interrupt configuration
    b9540476549 net/virtio: fix split queue vectorized Rx
    24ae55b075d net/virtio: fix mbuf count on Rx queue setup
    8cbd4cec761 net: fix checksum offload for outer IPv4
    7e0a1eee891 ethdev: fix typo in Rx queue setup API comment
    fcece17c517 eal: fix memory leak when saving arguments
    64c61201859 examples/service_cores: fix lcore count check
    8192dfc3884 test/func_reentrancy: free memzones after test
    91f3769c3fa build: propagate Windows system dependencies to pkg-config
    8404c8c99a3 net/ice: fix performance with writeback policy
    d9958c19076 net/ixgbe: fix mbuf leak
    a1ebe4da329 net/ixgbe: fix MAC resource leak
    5787cc1187e net/ixgbe: fix queue resource leak
    c1723e2d140 net/ixgbe: fix hash handle leak
    ed49cafb257 net/sfc: set FDIR bit for flow mark in EF100 Rx
    dd8e8fcf1ff net/hns3: fix taskqueue pair reset command
    0c355fecc0a net/hns3: fix queue flow action validation
    6b6aacee710 net/pcap: fix resource leakage on port probe
    a202064ef3f net/axgbe: fix unreleased lock in I2C transfer
    19acac8cef9 doc: fix bonding driver name
    af6efb8cb21 net/af_xdp: fix zero-copy Tx queue drain
    fc300c1c4a2 net/bnxt: fix double allocation of ring groups
    8516f354566 net/bnxt: fix ring group free
    ddc5464088d net/bnxt: check FW capability for VLAN offloads
    16f8bcc3d8d net/bnxt: fix mbuf VLAN in scalar Rx
    9f02c498bf8 net/ixgbe: fix Rx multicast statistics after reset
    c660ad64aae net/iavf: fix overflow in maximum packet length config
    073599bf922 net/ice: fix queue config in DCF
    7722837b520 net/ice: fix deadlock on flow query
    e244e8c066d net/ice: fix RXDID default value in DCF
    34a2e17afc4 net/ice: fix memzone leak after device init failure
    877a05209a2 net/nfp: fix minimum descriptor sizes
    1f83882dacc common/dpaax/caamflib: fix IV for short MAC-I in SNOW3G
    52ed92cfb6b crypto/openssl: fix CCM processing 0 length source
    c3672a36e6f config/ppc: ignore GCC 11 psabi warnings
    9102608a1cf eal/ppc: ignore GCC 10 stringop-overflow warnings
    e4509540bed crypto/octeontx2: fix unaligned access to device memory
    6e5dbe15864 app/testpmd: fix dump of Tx offload flags
    3dc611ee158 app/testpmd: fix check without outer checksum
    8f75f8b5886 net/bnxt: fix crash after port stop/start
    d53332318f5 app/testpmd: fix Tx retry in flowgen engine
    83ec79465d8 net/bnxt: update ring group after ring stop start
    4ba7ab1ebd5 net/mlx5: fix eCPRI matching
    f50cec54fd7 net/mlx5: fix mbuf replenishment check for zipped CQE
    05af857e430 net/txgbe: fix reading SFP module SFF-8472 data
    e2eae487932 net/ice: fix max entry number for ACL normal priority
    2cbc3c42d22 net/ice/base: fix typo in comment
    39a30eb8841 drivers/net: fix vector Rx comments
    99e95a04c40 drivers/net: fix typo in vector Rx comment
    d65672bac2e examples/performance-thread: fix build with clang 12.0.1
    cd9f079d879 net/i40e: support 25G AOC/ACC cables
    cfcca699036 version: 20.11.3
    fcdf769a989 test/power: fix CPU frequency when turbo enabled
    ede02cfc478 net/mlx5: fix imissed statistics
    c5f4e9dd155 version: 20.11.3-rc1
    62ff84ca2a6 app/testpmd: fix IPv4 checksum
    bf76709d20d bus: clarify log for non-NUMA-aware devices
    53193aeeba4 net/mlx5: workaround drop action with old kernel
    12cc60e507c doc: update atomic operation deprecation
    78b8978ef74 doc: remove old deprecation notice for sched
    cf52376b2d0 doc: fix spelling
    853a9877165 crypto/qat: disable asymmetric crypto on GEN3
    fb63987b6d5 crypto/octeontx: fix freeing after device release
    151569886c1 cryptodev: fix freeing after device release
    946df437470 eal/windows: cleanup virt2phys handle
    d06cadbbbd9 eventdev: fix event port setup in Tx adapter
    c9c391ea608 app/testpmd: fix Tx checksum calculation for tunnel
    3a0ced629fd net/softnic: fix memory leak as profile is freed
    c3e2390817b net/softnic: fix null dereference in arguments parsing
    d43a754af85 net/memif: fix abstract socket address length
    62a186761fd net/ena: enable multi-segment in Tx offload flags
    72f6920480c net/mlx5: add Tx scheduling check on queue creation
    f46e2c750ac net/mlx5: fix timestamp initialization on empty clock queue
    0564825638a net/mlx5: fix flow engine type in function name
    4ac789fddc8 net/mlx5: fix default queue number in RSS flow rule
    38779aa845b net/mlx5: fix RSS flow rule with L4 mismatch
    f67d7c848e2 net/mlx5: fix queue leaking in hairpin auto bind check
    3003560e240 net/mlx5: fix representor interrupt handler
    ad67a31e0aa net/iavf: fix Tx threshold check
    13ac5a51019 net/virtio: fix default duplex mode
    f21bc781750 net/virtio: fix interrupt handle leak
    dc023498c91 vhost: fix crash on reconnect
    47d67fb4bbf net/virtio: report maximum MTU in device info
    84a32847c98 net/octeontx2: fix default MCAM allocation size
    2f39890f4a7 app/testpmd: fix MAC address after port reset
    d0eebf4a009 app/testpmd: fix help string for port reset
    36c937ac722 sched: rework configuration failure handling
    41a170fc81d sched: fix profile allocation failure handling
    0cd4f7ee81a net/sfc: fix MAC stats update for stopped device
    b84a0ebd171 net/sfc: fix xstats query by unsorted list of IDs
    e4ebfdeb0d0 net/sfc: fix xstats query by ID according to ethdev
    99bcdae0147 net/sfc: fix reading adapter state without locking
    e5e8e0aa61a net/sfc: fix MAC stats lock in xstats query by ID
    4b44020ca7a net/dpaa: fix headroom in VSP case
    b2ac79d89a4 bus/dpaa: fix freeing in FMAN interface destructor
    66d9de1cde0 net/ena: trigger reset on Tx prepare failure
    f91f60bb479 net/hinic: fix MTU consistency with firmware
    3e6a9fa0e2a net/hinic/base: fix LRO
    2ca9d750c9a net/hinic: increase protection of the VLAN
    4e210bb1419 net/hns3: fix Tx prepare after stop
    28a94eea0c5 net/hns3: fix flow rule list in multi-process
    fc0e7a4358b net/hns3: fix timing of clearing interrupt source
    01dcb161868 net/hns3: fix filter parsing comment
    471ed659c17 net/hns3: fix residual MAC address entry
    752b19f91f5 net/softnic: fix memory leak in arguments parsing
    ce81944f3dc eal/windows: check callback parameter of alarm functions
    806a18751b2 net/bnxt: fix null dereference in interrupt handler
    3e8a6d6b1d9 net/bnxt: remove workaround for default VNIC
    03348e9bec4 net/mlx5: export PMD-specific API file
    d0213e26bbb net/mlx5: reject inner ethernet matching in GTP
    cf3ae2009ce net/mlx5: fix RSS expansion for GTP
    3fd282e7287 net/mlx5: fix RoCE LAG bond device probing
    453f8bb2351 net/mlx5: fix indirect action modify rollback
    a20d4d2506d net/mlx5: fix Rx/Tx queue checks
    da1a6d5e462 regex/mlx5: fix redundancy in device removal
    0760fa23a07 net/mlx5: fix overflow in mempool argument
    c571fde575c vdpa/mlx5: fix overflow in queue attribute
    4eb4301b074 regex/mlx5: fix size of setup constants
    a961df1650d net/virtio: fix Rx scatter offload
    e1b663f8b36 vhost: fix lock on device readiness notification
    12e277dee62 net/virtio: fix refill order in packed ring datapath
    2df90802c6f vhost: check header for legacy dequeue offload
    db878744bc3 test/crypto: fix mempool size for session-less
    89d903beb47 crypto/octeontx2: fix lookaside IPsec IV pointer
    48181d181df crypto/octeontx2: fix IPsec session member overlap
    7bbe2749581 test/power: fix CPU frequency check for intel_pstate
    1f4a450852e raw/ioat: fix config script queue size calculation
    133edc5f0fc distributor: fix 128-bit write alignment
    fc9d2f0dbe6 net/bnxt: clear cached statistics
    3f2f6be303b net/bnxt: fix nested lock during bonding
    5584a03fe99 net/bnxt: fix missing barriers in completion handling
    f58d25a5790 net/octeontx2: fix TM node statistics query
    6595f06986d net/mvpp2: fix configured state dependency
    9c8609a3561 net/mvpp2: fix port speed overflow
    ef16dc1cc89 net/mlx5: fix typo in vectorized Rx comments
    4c8e04c0561 net/mlx5: fix threshold for mbuf replenishment in MPRQ
    a6a787bf7d9 net/mlx5: fix missing RSS expansion of IPv6 frag
    5b34c2ad6f1 net/mlx5: fix missing RSS expandable items
    2a5c46697b2 net/mlx5: remove redundant operations in NEON Rx
    a5fb806241d app/testpmd: fix offloads for newly attached port
    96ad1e25fc0 net/softnic: fix connection memory leak
    6807067d712 net/bonding: check flow setting
    2b916ad7eb7 net/bonding: fix error message on flow verify
    e77955f0edc net/bnxt: fix ring allocation and free
    2346170dd31 net/bnxt: detect bad opaque in Rx completion
    d375abc7177 table: fix bucket empty check
    4b8bd031fe8 net/hns3: fix Arm SVE build with GCC 8.3
    2bf923fc8f6 net/virtio: fix aarch32 build
    39156c32083 net/bnxt: fix aarch32 build
    7590791b9e8 net/sfc: fix aarch32 build
    2da39fd204f build: support drivers symlink on Windows
    fd2f9a4932a doc: fix build on Windows with Meson 0.58
    97d5862b30c net/octeontx/base: fix debug build with clang
    d232a49bf4f net/ixgbe: fix flow entry access after freeing
    7cdf5af8091 net/i40e: fix descriptor scan on Arm
    ebe009027ce net/ice: fix memzone leak when firmware is missing
    386524e3f59 common/mlx5: fix compatibility with OFED port query API
    32b98abf1b4 common/mlx5: use new port query API if available
    10beb1ace1f net/mlx5: fix MPLS RSS expansion
    29c7cf41a22 net/mlx5: remove unsupported flow item MPLS over IP
    d709081562e common/mlx5: fix Netlink receive message buffer size
    0e61040a35a net/mlx5: fix match MPLS over GRE with key
    6452e165dff net/mlx5: fix pattern expansion in RSS flow rules
    c1ed88d89bc net/mlx5: fix r/w lock usage in DMA unmap
    ce3be500346 doc: add limitation for ConnectX-4 with L2 in mlx5 guide
    79bd409861b net/mlx5: fix TSO multi-segment inline length
    1e2b9848ab5 common/mlx5: fix memory region leak
    06e38e2e836 net/mlx5: fix multi-segment inline for the first segments
    98d41069f10 net/bnxt: fix Rx interrupt setting
    ec202acb1c2 net/bnxt: fix scalar Tx completion handling
    8eb3ca3f925 net/bnxt: fix Tx descriptor status implementation
    0e27d706043 net/bnxt: fix ring and context memory allocation
    43bcce71fe2 net/bnxt: invoke device removal event on recovery failure
    6d2d072cc18 net/bnxt: fix auto-negociation on Whitney+
    39d5e6fea3f net/bnxt: fix typo in log message
    a12b17cb05a net/bnxt: cleanup code
    8a742f542ca ipc: stop mp control thread on cleanup
    fba329627dd crypto/mvsam: fix options parsing
    1a3903c0d3e crypto/mvsam: fix session data reset
    bbfd3f227b8 crypto/mvsam: fix capabilities
    929b5fec9da crypto/mvsam: fix AES-GCM session parameters
    a3c1ad39e46 test/crypto: fix typo in ESN case
    cc483227201 test/crypto: fix typo in AES case
    bb9d13ec90e test/crypto: fix autotest function parameters
    a1242338e19 crypto/aesni_gcm: fix performance on some AVX512 CPUs
    a5405a2eba3 test/crypto: fix mbuf reset after null check
    63f28457dc8 app/crypto-perf: fix out-of-place mempool allocation
    1b7530a088e crypto/qat: fix Arm build with special memcpy
    85c2f7fed5c app/testpmd: change port link speed without stopping all
    55585a5f1a7 ethdev: fix doc of flow action
    4f3fba99a72 app/testpmd: fix type of FEC mode parsing output
    b4d36b226b5 net/tap: fix Rx checksum flags on TCP packets
    936bdd642b3 net/tap: fix Rx checksum flags on IP options packets
    dccbbfc8ee6 net/sfc: fix outer L4 checksum Rx
    e942ab21448 net/pfe: remove unnecessary null check
    2799483e120 net/hns3: fix maximum queues on configuration failure
    2157046ca0b net/hns3: fix VLAN strip log
    bf6bd022ef5 net/hns3: fix fake queue rollback
    14a0af59947 net/hns3: fix delay for waiting to stop Rx/Tx
    24dc86183de net/hns3: increase VF reset retry maximum
    21ec6d9eb2c drivers/net: fix memzone allocations for DMA memory
    55b7e77a7db net/sfc: fix outer match in MAE backend
    b19930090a0 net/sfc: check ID overflow in action port ID
    97fcc59a870 mempool/octeontx2: fix shift calculation
    7009b90679a vdpa/mlx5: fix TSO offload without checksum
    cb97272d8ee vhost: fix NUMA reallocation with multi-queue
    1b6e6c17546 vhost: fix missing guest pages table NUMA realloc
    2412914cdb0 vhost: fix missing memory table NUMA realloc
    b386dd5b4b5 net/i40e: fix multi-process shared data
    142e3badc29 net/i40e: fix flow director input set conflict
    ef03fc3f016 net/ice: fix overflow in maximum packet length config
    0ac008ccca1 net/octeontx2: use runtime LSO format indices
    b1cb0f2fcb9 net/octeontx2: fix flow creation limit on CN98xx
    b719b896245 test/mbuf: fix virtual address conversion
    a2d9e63eecf bus/pci: fix leak for unbound devices
    c24244d08f4 examples/l2fwd: fix [no-]mac-updating options
    8f9f2da7e34 app/test: fix IPv6 header initialization
    ef0558c8bea bus/pci: fix IOVA as VA support for PowerNV
    f0847028f36 common/mlx5: fix Netlink port name padding in probing
    6b23ae0cad3 net/mlx5: fix IPIP multi-tunnel validation
    63c0a9b54e5 net/mlx5: fix switchdev mode recognition
    82758719aa1 net/mlx5: fix RSS pattern expansion
    b6690ca0b1a tests/eal: fix memory leak
    72bff6df5f1 tests/cmdline: fix memory leaks
    d4a803fd539 rib: fix max depth IPv6 lookup
    36dbd9df876 flow_classify: fix leaking rules on delete
    16d0682d672 kni: fix crash on userspace VA for segmented packets
    3fc6330a65a kni: fix mbuf allocation for kernel side use
    979fecc8574 vhost/crypto: check request pointer before dereference
    bd03c14aaf5 devtools: fix file listing in maintainers check
    5ca9e6b50d5 vfio: add stdbool include
    24b3c181270 doc: fix default burst size in testpmd
    6dfb0b782fd doc: fix typo in SPDX tag
    ac4a67a5f99 net/iavf: fix scalar Rx
    5f70ea4e973 net/i40e: fix use after free in FDIR release
    1050357ef7e net/ice: fix data path in secondary process
    744e86e0892 net/ice: fix data path selection in secondary process
    18db4a4d845 net/i40e: fix raw packet flow director
    d5052b1a2e1 net/iavf: fix handling of unsupported promiscuous
    ea3ef0c977a net/ice: fix default RSS key generation
    58fbfecc2a1 net/iavf: fix RSS key access out of bound
    70b84a4e1b6 net/bnxt: remove unnecessary comment
    386efec3809 net/bnxt: improve probing log message
    a2e10ac19d6 net/bnxt: fix check for PTP support in FW
    92e631ec91e net/bnxt: use common function to free VNIC resource
    cb99c42fe0a net/bnxt: set flow error after tunnel redirection free
    2f6cc4ff5f5 net/bnxt: fix error handling in VNIC prepare
    3d3770a60f4 net/bnxt: remove unnecessary code
    da7d8b7da30 net/bnxt: set flow error when free filter not available
    78f6a49fd49 net/bnxt: fix error messages in VNIC prepare
    47b40639d90 net/bnxt: workaround spurious zero stats in Thor
    70314ce0288 net/bnxt: fix Rx burst size constraint
    d19b2017fcb net/bnxt: check access to possible null pointer
    73b4b37a14f malloc: fix size annotation for NUMA-aware realloc
    cd12bf53578 bitmap: fix buffer overrun in bitmap init
    7af7de2a52c graph: fix null dereference in stats
    3d328cf711b graph: fix memory leak in stats
    a8602474838 version: 20.11.2
    aac916d95c7 version: 20.11.2-rc2
    8db55d6a07e net/mlx5: fix receiving queue timestamp format
    6b3e11c79d0 net/ice: fix RSS for L2 packet
    f7b699f8e10 event/octeontx2: fix XAQ pool reconfigure
    a0481453afc event/octeontx2: configure crypto adapter xaq pool
    a71455d9f51 event/octeontx2: fix crypto adapter queue pair operations
    ffa8fb5f542 build: fix drivers selection without Python
    d997326fe34 net/ark: fix leak on thread termination
    e11b10e00a4 net/hns3: fix concurrent interrupt handling
    621a74d8287 test/cmdline: silence clang 12 warning
    bd41e2bc99d doc: fix runtime options in DLB2 guide
    8ba82ed84d5 event/dlb2: remove references to deferred scheduling
    4d182a84d5a test: fix build with GCC 11
    0b1753ac726 net/memif: fix Tx bps statistics for zero-copy
    b1ec8ac5ec3 common/sfc_efx/base: add missing MCDI response length checks
    6f41c82e526 common/sfc_efx/base: limit reported MCDI response length
    83fcaa37fe8 net/mlx5: fix loopback for Direct Verbs queue
    91f0c38c0d6 net/hns3: fix link speed when VF device is down
    f4a3f4a6b91 net/hns3: fix DCB reconfiguration
    0eafb399ba3 net/hns3: fix DCB configuration
    aeaba9b829a net/hns3: remove meaningless packet buffer rollback
    47af5229ce0 net/hns3: fix requested FC mode rollback
    6442b978949 net/hns3: fix Rx/Tx queue numbers check
    a6967ee4a8c vdpa/mlx5: fix device unplug
    4079bce2049 net/vhost: restore pseudo TSO support
    d565e160b11 net/mlx5: fix counter offset detection
    570fa795f08 net/mlx5: fix leak when configured repeatedly
    2471e99da32 net/mlx4: fix leak when configured repeatedly
    6156da10414 crypto/zuc: fix build with GCC 11
    87eec97f524 test/crypto: fix build with GCC 11
    18918e1884a devtools: fix orphan symbols check with busybox
    934abbb8b8c test: fix division by zero
    99755af6748 examples/l3fwd-power: fix empty poll thresholds
    64ac670fa00 test/table: fix build with GCC 11
    61238b46be3 test/power: fix turbo test
    4498bac0f5d test/power: fix low frequency test when turbo enabled
    c5a5a60d9e1 test/power: add turbo mode to frequency check
    c729d4f1253 test/power: fix CPU frequency check
    9a1044da257 test: check flow classifier creation
    acf64e96854 examples/skeleton: fix NUMA check of port and core
    12822e56a09 examples/l2fwd-cat: fix NUMA check of port and core
    110a22070f7 examples/flow_classify: fix NUMA check of port and core
    b993ebf7bbd examples/rxtx_callbacks: fix port ID format specifier
    fc88e04a9ab app/crypto-perf: check memory allocation
    cfd635034c7 crypto/qat: fix null authentication request
    010e63f5eef test/crypto: fix return value of a skipped test
    975a9831e17 net/mlx5: fix RSS flow item expansion for NVGRE
    cb97d594287 net/mlx5: fix secondary process initialization ordering
    14b6df2399e net/mlx4: fix secondary process initialization ordering
    071855618a6 net/tap: fix build with GCC 11
    c2155d82976 net/ice/base: fix build with GCC 11
    84c5ec25056 net/bnx2x: fix build with GCC 11
    724378c1a14 net/bnx2x: fix build with GCC 11
    a83980d0798 net/igc: fix speed configuration
    e0305fc830c net/i40e: fix VF RSS configuration
    2e077407fee net/ice: fix VSI array out of bounds access
    e5c01fbc22f net/ena: indicate Rx RSS hash presence
    96883cec2af net/mlx5: fix tunnel offload private items location
    6bdf3844471 net/enic: enable GENEVE offload via VNIC configuration
    1cf7b4c7692 net/ice: fix leak on thread termination
    18151dfdcb4 app/testpmd: fix tunnel offload flows cleanup
    98f23aad564 net/hns3: fail setting FEC if one bit mode is not supported
    a6c272ac76c net/hns3: fix ordering in secondary process initialization
    edd8521ace0 net/hns3: fix secondary process request start/stop Rx/Tx
    a795428a299 net/hns3: fix mailbox message ID in log
    5244852443b net/hns3: fix TM QCN error event report by MSI-X
    ec14e372203 net/txgbe: fix QinQ strip
    33f33e3e7c4 net/hns3: fix querying flow director counter for out param
    8e72b7a2eef net/hns3: fix VF alive notification after config restore
    6ed898b2971 net/hns3: clear hash map on flow director clear
    8f93ec62881 net/hns3: fix log on flow director clear
    9e15a154c5a net/hns3: return error on PCI config write failure
    3387f2c95ff net/nfp: fix reporting of RSS capabilities
    c9000c686e2 net/ena: report default ring size
    4a79d25bd19 net/ena: remove endian swap functions
    967dcfb168c net/ena: fix crash with unsupported device argument
    a5c0cca39ad net/ena: fix parsing of large LLQ header device argument
    1c44277b563 net/ena/base: destroy multiple wait events
    74cc4f7d974 net/ena/base: fix type conversions by explicit casting
    47ed9f3e81c net/ena/base: improve style and comments
    70f1f80edb6 net/ena: switch memcpy to optimized version
    48af30a4c38 net/mlx5/linux: fix firmware version
    106f00833d1 net/mlx5: fix RSS flow item expansion for GRE key
    6db31e33044 net/ice/base: fix memory allocation wrapper
    d8351b6c9f3 app/eventdev: fix lcore parsing skipping last core
    d4138b565da event/dpaa2: remove unused macros
    b7ab9f121d7 power: fix sanity checks for guest channel read
    5d30751003c doc: remove PDF requirements
    14e975dea92 test/timer: check memzone allocation
    3ce8842e183 examples/timer: fix time interval
    764a01e1457 ipc: use monotonic clock
    45c0d2e47e4 raw/skeleton: add missing check after setting attribute
    3aadd33dd27 eal: fix memory mapping on 32-bit target
    3cb6827a324 eal: fix leak in shared lib mode detection
    5be4837391f bus/fslmc: remove unused debug macro
    07d17061abb test/crypto: copy offset data to OOP destination buffer
    e5bf617fa8b crypto/dpaa2_sec: fix close and uninit functions
    39b13992e9c crypto/dpaa_sec: affine the thread portal affinity
    8038030f29b test/crypto: fix auth-cipher compare length in OOP
    afe3a7f202a compress/qat: enable compression on GEN3
    95fd32f696a common/qat: increase IM buffer size for GEN3
    6856433bed4 app/bbdev: fix HARQ error messages
    90ca87dd693 app/bbdev: check memory allocation
    2194792b3ac eal: fix service core list parsing
    689d3a982bc ipc: check malloc sync reply result
    89bbedc455d raw/ntb: check memory allocations
    1a62a37afe1 raw/ntb: check SPAD user index
    10ddae775cb examples: fix pkg-config override
    8ff559890ac regex/octeontx2: remove unused include directory
    a0a21cb0c7f net/bnxt: prevent device access in error state
    00b23432391 net/bnxt: fix mismatched type comparison in Rx
    e00127b7777 net/bnxt: check PCI config read
    91d4a1731ab net/bnxt: fix mismatched type comparison in MAC restore
    1cfcaccb0bd net/bnxt: fix single PF per port check
    85b0241b6b9 net/bnxt: fix dynamic VNIC count
    a7375b06e87 net/bnxt: fix Rx timestamp when FIFO pending bit is set
    699e70a0b61 net/bnxt: refactor multi-queue Rx configuration
    ca60f848236 vhost: fix offload flags in Rx path
    96c209b1a6b net/virtio: fix vectorized Rx queue rearm
    b6659faacc1 telemetry: fix race on callbacks list
    31619530c8f test/distributor: fix burst flush on worker quit
    8e681713b3c test/distributor: fix worker notification in burst mode
    8064f75d9b2 ethdev: add missing buses in device iterator
    8e6d9cfe2d1 net/hns3: increase readability in logs
    ce498169d47 net/hns3: remove unused VMDq code
    5d84f2b422a net/hns3: remove read when enabling TM QCN error event
    29da2a8b3d1 net/hns3: fix vector Rx burst limitation
    88be45dbba7 net/bnxt: drop unused attribute
    15cf480f1a9 net/sfc: fix mark support in EF100 native Rx datapath
    40c046441f3 net/i40e: fix primary MAC type when starting port
    38b01e7fa31 net/iavf: fix primary MAC type when starting port
    5c4358f0542 raw/ifpga: fix device name format
    cb6f74724dc net/mlx5: fix flow age event triggering
    053299cf1df net/hns3: remove unused macros
    2f0e34a5750 net/hns3: fix time delta calculation
    589600a03af net/hns3: log time delta in decimal format
    1f6d0c6f6c4 app/testpmd: verify DCB config during forward config
    313bd50dab1 app/testpmd: fix DCB re-configuration
    a3da2073491 app/testpmd: fix DCB forwarding configuration
    95d258ab144 app/testpmd: fix forward lcores number for DCB
    9874e06dc57 net/kni: warn on stop failure
    3caffc54475 net/tap: check ioctl on restore
    6af34d2abd2 app/testpmd: fix division by zero on socket memory dump
    180a37c3ef2 net/hns3: fix link speed when port is down
    3502d412a05 net/hns3: fix link status when port is stopped
    47b2b44b9fc net/mlx5: fix probing device in legacy bonding mode
    1c43f69982f net/mlx4: fix buffer leakage on device close
    04475743c84 net/mlx5: remove drop queue function prototypes
    8965b668960 net/bnxt: use prefix on global function
    52d2337eac0 net/bnxt: remove unused function parameters
    5396d57fc3e net/bnxt: remove unnecessary forward declarations
    0f0469489b1 net/virtio: fix getline memory leakage
    24743b77a73 vhost: fix redundant vring status change notification
    b0a7aab7d88 vhost: fix queue initialization
    351bc346454 net/e1000: fix flow error message object
    5d2c2857f43 common/iavf: fix duplicated offload bit
    dc22d3cfab6 net/iavf: fix VF to PF command failure handling
    e488fd804d5 net/ice: fix fast mbuf freeing
    c7db9596130 net/i40e: remove redundant VSI check in Tx queue setup
    35e133887c6 net/i40e: fix negative VEB index
    3085e8ab3e3 common/sfc_efx/base: fix dereferencing null pointer
    551f3198b8f net/hns3: fix handling link update
    adefa69ef3d net/bonding: fix socket ID check
    8d04d026a74 doc: fix formatting in testpmd guide
    9886a1aed2b app/testpmd: fix segment number check
    bef47e0c78c net/hns3: fix typos on comments
    58155c9ecf4 net/tap: fix interrupt vector array size
    6ca567cc48c app/testpmd: fix max queue number for Tx offloads
    eaee68d8527 test/kni: check init result
    3b949ee57a0 test/kni: fix a comment
    448c880b6e9 net/bonding: fix leak on remove
    8abec7f3176 net/hns3: remove unused mailbox macro and struct
    b012ce6634a net/hns3: fix processing link status message on PF
    b47af28ffd1 net/hns3: fix mailbox error message
    3ab9cfbc6a6 drivers/net: fix FW version query
    b65e812dd26 net/kni: check init result
    bfaab1571e5 doc: fix multiport syntax in nfp guide
    7abfd667dae power: save original ACPI governor always
    2c6016c807a bpf: fix JSLT validation
    a5fd2098d6e acl: fix build with GCC 11
    efdd260f6ee eventdev: fix memory leakage on thread creation failure
    78dfdbc90f9 eventdev: remove redundant thread name setting
    d173cc85c98 app/eventdev: fix overflow in lcore list parsing
    8ad8d124a55 test/mempool: fix object initializer
    f532cbbedb9 mbuf: check shared memory before dumping dynamic space
    5f90abb2326 eal/arm64: fix platform register bit
    35ad25c5b12 raw/ioat: fix script for configuring small number of queues
    1c96bfbc4c7 config/ppc: reduce number of cores and NUMA nodes
    cf948fe9c52 stack: allow lock-free only on relevant architectures
    ad11991368c version: 20.11.2-rc1
    06ed5a27296 app: fix exit messages
    3dce6da8bce bus/pci: support I/O port operations with musl
    8aeb5c35383 net/bnxt: fix ring count calculation for Thor
    d225df791f5 regex/mlx5: support timestamp format
    1607156dcdc net/mlx5: support timestamp format
    2ceb5afbf27 doc: fix build with Sphinx 4
    7fbddcaa0e0 net/bnxt: fix PTP support for Thor
    05d828f0b65 net/bnxt: fix Rx queue count
    189a17d086e net/bnxt: fix Rx descriptor status
    51fef82607c net/sfc: fix outer rule rollback on error
    1524a5460b1 net/hns3: fix verification of NEON support
    c6bc1e8980a net/hns3: fix timing in mailbox
    41b26802273 net/hns3: fix VF handling LSC event in secondary process
    58d88505533 net/hns3: fix possible mismatched response of mailbox
    595ee1c60ac net/virtio: fix interrupt unregistering for listening socket
    442a4977a97 net/iavf: fix wrong Tx context descriptor
    6a6af19db54 net/hns3: fix setting default MAC address in bonding of VF
    d24915f0728 net/hns3: fix mbuf leakage
    67fe9bc80f3 ci: catch coredumps
    0f9f25a1d1d ci: ignore APT update failure in GitHub Actions
    a93e472781a ci: fix package installation in GitHub Actions
    2f415afb561 ci: enable v21 ABI checks
    bb63ff4aa14 ci: hook to GitHub Actions
    92ef3bbc7a8 kni: fix kernel deadlock with bifurcated device
    d4d212786a3 kni: refactor user request processing
    0cf8916e01b kni: support async user request
    20bbce05a8f doc: fix names of UIO drivers
    7d3e01ef101 net/e1000/base: fix timeout for shadow RAM write
    bd0291a99ab net/i40e: fix flow director for common pctypes
    abb66bf4639 net/ice: fix disabling promiscuous mode
    32698b8d325 net/hns3: remove unused macro
    8d6377e1725 net/igc: fix Rx packet size
    608d69a62fd net/bnxt: fix health check alarm cancellation
    8ffdca19f32 net/bnxt: fix resource cleanup
    9231460d33c net/bonding: fix adding itself as its slave
    ba1a310e046 net/hns3: fix flow director lock
    5eaa5abcd8d net/hns3: fix VMDq mode check
    cdffbfb77ff net/hns3: fix DCB mode check
    2782c994db5 net/hns3: remove redundant mailbox response
    5c61f0e991f doc: fix matching versions in ice guide
    bd0494c495a net/hns3: remove unused macros
    f81a67f4b8c doc: fix HiSilicon copyright syntax
    1eea3b7a270 examples/ethtool: remove unused parsing
    aa94d640eb5 examples: add eal cleanup to examples
    8347ba1646e test/power: round CPU frequency to check
    2266f65a23e test/power: add delay before checking CPU frequency
    323d01cf8d9 test/bpf: fix error message
    79273b13a09 common/dpaax: fix possible null pointer access
    1bcde228269 sched: fix traffic class oversubscription parameter
    9ffa1fee270 ip_frag: fix fragmenting IPv4 packet with header option
    b6b219b87c1 test: check thread creation
    7b3cbf53151 test/cmdline: fix inputs array
    c62ae18b64d examples/l3fwd: fix LPM IPv6 subnets
    512393d56e5 examples/ptpclient: remove wrong comment
    51ca4146bb2 pipeline: fix endianness conversions
    6b76e061083 vfio: fix duplicated user mem map
    879dc56ebd8 eventdev: fix case to initiate crypto adapter service
    86ec5aeef9e net/iavf: fix lack of MAC type when set MAC address
    674d4cb4de0 net/i40e: fix lack of MAC type when set MAC address
    6ac6d7e8527 net/hns3: fix flow control mode
    20a6184f88c net/hns3: remove VLAN/QinQ ptypes from support list
    dc7d0634158 net/hns3: fix missing outer L4 UDP flag for VXLAN
    f20ccda35a7 net/hns3: fix use of command status enumeration
    a0cffe358de net/ice: fix crash in AVX512
    b59be07a774 net/iavf: fix crash in AVX512
    5ecc163bf94 ethdev: update flow item GTP QFI definition
    42c05be1fe0 app/testpmd: fix bitmap of link speeds when force speed
    be168e4fec6 net/ixgbe: fix Rx errors statistics for UDP checksum
    8e59d734a21 net/mlx5: fix resource release for mirror flow
    00d769c5184 net/mlx4: fix RSS action with null hash key
    fb455a8129a net/mlx5: fix redundant flow after RSS expansion
    1cb30b35c90 net/ice: fix illegal access when removing MAC filter
    ac002ace6e9 net/e1000: fix max Rx packet size
    9c9d25bce19 common/sfc_efx/base: fix indication of MAE encap support
    41111ae6237 net/hns3: fix configure FEC when concurrent with reset
    33c960aad1e net/hns3: fix queue state when concurrent with reset
    da8413c234c net/hns3: fix timing in resetting queues
    94bb3ef9887 net/hns3: fix some packet types
    60065a5a61d test: fix TCP header initialization
    3d8025a1215 buildtools: fix all drivers disabled on Windows
    acbb986965b crypto/qat: fix offset for out-of-place scatter-gather
    ce88f40d2ce examples/l2fwd-crypto: fix packet length while decryption
    9c07408cef2 examples/l2fwd-crypto: skip masked devices
    96d2d64bf10 crypto/octeontx: fix session-less mode
    9e520a5a7aa eal: add C++ include guard for reciprocal header
    45b58e4ac44 raw/octeontx2_dma: assign PCI device in DPI VF
    d2d434683d8 test/trace: fix race on collected perf data
    cf45856b8be license: fix typos
    eb30365e9ec event/octeontx2: fix device reconfigure for single slot
    dc7e8df00fa app/eventdev: fix timeout accuracy
    5b91f48bc81 test/event: fix timeout accuracy
    ba0aecb72a6 eal/windows: fix return codes of pthread shim layer
    2e83b42a993 app/flow-perf: fix encap/decap actions
    2b03f8ca36f net/enic: fix flow initialization error handling
    44bd01347fc net/hns3: delete redundant blank line
    7764ed833a2 net/hns3: support get device version when dump register
    d0897ad2fbd net/hns3: fix VF mailbox head field
    bb24098f63c net/hns3: fix flow counter value
    654aeb26190 net/hns3: fix flow control exception
    73db182cb0e net/hns3: fix rollback after setting PVID failure
    c718e751f43 net/hns3: fix FLR miss detection
    539f3b78020 net/hns3: fix copyright date
    a096b11ef5d ethdev: validate input in EEPROM info
    963fcacd956 ethdev: validate input in register info
    2e6638d8979 ethdev: validate input in module EEPROM dump
    ec4d4d10f36 vhost: fix initialization of async temporary header
    de93dc05020 vhost: fix initialization of temporary header
    d43a7f6be8e net/bnxt: fix configuring LRO
    bc53c25124f net/bnxt: fix double free in port start failure
    f30dc57e785 net/mlx5: fix drop action for Direct Rules/Verbs
    b52bd28182d net/mlx5: fix missing shared RSS hash types
    43af55f5bfb net/mlx5: fix shared inner RSS
    81c1c910372 net/i40e: fix flow director config after flow validate
    5a4a7bb8306 doc: update recommended versions for i40e
    b1fab4dc0d5 net/e1000: fix Rx error counter for bad length
    fa6df61bf20 net/igc: fix Rx error counter for bad length
    13e3e5e93c0 net/ena: fix releasing Tx ring mbufs
    7151983d32f net/hns3: update HiSilicon copyright syntax
    fdd1a587627 net/hns3: fix MTU config complexity
    1324beafbae eal: fix hang in control thread creation
    ea6d0d65619 eal: fix race in control thread creation
    5a324f3e4d3 app/testpmd: fix usage text
    7b581788eec app/regex: fix usage text
    3ad213dfa73 eal: fix evaluation of log level option
    4fc1996894b test: proceed if timer subsystem already initialized
    92805a55dad drivers: fix log level after loading
    6baf95a98d5 service: clean references to removed symbol
    e0a41b8c471 mem: fix freeing segments in --huge-unlink mode
    8ee0fdee90d power: do not skip saving original P-state governor
    43708086402 doc: fix sphinx rtd theme import in GHA
    8d3f8b347f6 vdpa/mlx5: fix virtq cleaning
    42ed69a37be examples/vhost_crypto: remove unused short option
    429dd550359 vhost: fix batch dequeue potential buffer overflow
    358cba78c0b vhost: fix packed ring potential buffer overflow
    25d53e1eb8d vhost: fix split ring potential buffer overflow
    1716e668784 examples/vhost: check memory table query
    42457347e2a vdpa/ifc: check PCI config read
    f90c6e9d413 net/mlx5: fix using flow tunnel before null check
    7f55ac318c2 net/ixgbe: fix RSS RETA being reset after port start
    843b7caa8ef net/iavf: fix TSO max segment size
    eefc6b16bcd net/igc: fix Rx RSS hash offload capability
    8235f3fdfd9 net/i40e: announce request queue capability in PF
    ddb17b5462d net/iavf: fix packet length parsing in AVX512
    7f8de732281 net/i40e: fix parsing packet type for NEON
    38824647ed5 app/testpmd: fix Tx/Rx descriptor query error log
    cd33dd08a7a net/sfc: fix error path inconsistency
    de81fe259ae net/hinic: fix crash in secondary process
    a1b0bff2d5a net/hns3: fix long task queue pairs reset time
    15b6974306c net/hns3: fix link update when failed to get link info
    7537fafbc7d net/hns3: fix Tx checksum for UDP packets with special port
    a7bf8336a2d net/hns3: fix processing Tx offload flags
    e29b92b9982 net/hns3: fix reporting undefined speed
    530d228d3e4 net/mlx5: support RSS expansion for IPv6 GRE
    22910131391 net/mlx5: fix flow actions index in cache
    162f87fce1d net/ice/base: fix memory allocation for MAC addresses
    7b7af2fd731 net/ice: fix RSS hash update
    fe1461f8b60 net/i40e: fix input set field mask
    74fc31b48fc net/qede: accept bigger RSS table
    50650a3ab2d net/qede: reduce log verbosity
    75f780af8b8 net/bnxt: fix memory allocation for command response
    34972cfd968 net/bnxt: check kvargs parsing
    b1f8911ea3a net/bnxt: fix handling of null flow mask
    28e5e8b7220 net/bnxt: fix Tx length hint threshold
    b21daacf927 net/bnxt: fix Rx buffer posting
    6260a812821 net/bnxt: fix timesync when PTP is not supported
    23f07e5fdcd net/bnxt: fix link state operations
    88f2faa23cb net/bnxt: fix RSS context cleanup
    832c6464ce6 net/bnxt: fix PCI write check
    2b68ea0468f net/bnxt: fix Tx timestamp init
    763cb5c708a app/testpmd: fix NVGRE encap configuration
    516cebd9dd8 common/sfc_efx: remove GENEVE from supported tunnels
    b22415b70a6 net/ark: refactor Rx buffer recovery
    f6beb20cd91 net/ark: update packet director initial state
    d1b41662e06 test: fix autotest handling of skipped tests
    7c0c4418262 pipeline: fix instruction translation
    a8c9a82b541 examples/packet_ordering: fix port configuration
    67becbfe57c table: fix actions with different data size
    19bb5235f09 examples/bbdev: fix header include for musl
    ba7c3d6befb app/testpmd: fix build with musl
    0999e13c7ac event/dlb: fix header includes for musl
    c8f64e248df net/igc: remove use of uint type
    6bee873fbb8 net/cxgbe: remove use of uint type
    fc4664ada56 bus/dpaa: fix build with musl
    a01c94a0c3b bus/dpaa: fix 64-bit arch detection
    a4553bb9d24 common/dpaax/caamflib: fix build with musl
    efa745cbb2c eal: fix build with musl
    9c3bb2603c1 build: remove redundant _GNU_SOURCE definitions
    14702af2e52 build: detect execinfo library on Linux
    1555f48f85e buildtools: fix build with busybox
    838da368665 eal: fix comment of OS-specific header files
    cf102209461 net/mlx5: fix Rx metadata leftovers
    cd5184145e5 vdpa/mlx5: support timestamp format
    7ddf9eaed91 common/mlx5: add timestamp format support to DevX
    604068df872 net/ice: check some functions return
    9a7fd13201b app/testpmd: check MAC address query
    211541b6147 net/bnxt: fix Rx and Tx timestamps
    7c69b270937 net/bnxt: fix xstats get
    f061789e7cc net/bnxt: mute some failure logs
    15d81d5f9e3 net/bnxt: fix HWRM and FW incompatibility handling
    274ff8673a9 net/bnxt: fix VF info allocation
    3d051e75a45 net/bnxt: fix device readiness check
    2d5c1616053 net/bnxt: fix FW readiness check during recovery
    3fd1f9e8ec8 net/bnxt: fix firmware fatal error handling
    86e9785dbda net/bnxt: fix queues per VNIC
    74451465f7b net/bnxt: fix VNIC configuration
    262c0649f52 net/bnxt: remove unused macro
    7c078fd0e9e net: fix comment in IPv6 header
    a7e79f5d2c0 bus/pci: fix Windows kernel driver categories
    75c0d71c9f4 bus/pci: skip probing some Windows NDIS devices
    d68bec0b176 eal/windows: fix default thread priority
    87af5c70230 eal/windows: add missing SPDX license tag
    d43987787c0 log/linux: make default output stderr
    f59f4e98e49 build: exclude meson files from examples installation
    b66b37a2b53 net/octeontx2: fix VLAN filter
    6f1a03c53ef net/mlx5: fix Rx segmented packets on mbuf starvation
    d0de930b7b5 net/i40e: fix IPv4 fragment offload
    94610393111 net/i40evf: fix packet loss for X722
    0d32ae0c6f4 net/ice/base: cleanup filter list on error
    8d88d38931c net/ice/base: fix uninitialized struct
    d4ef2f169e4 net/ice/base: fix payload indicator on ptype
    e3486cbde8e net/e1000: remove MTU setting limitation
    f9b6f0ca8b3 net/igc: remove MTU setting limitation
    f27ac1c0093 net/ice: fix VLAN filter with PF
    58fc7f65f2c net/txgbe: update packet type
    4d4ae30d079 net/txgbe: fix Rx missed packet counter
    991c44b2575 net/txgbe: remove unused functions
    96cc541d111 net/bonding: fix LACP system address check
    19922dfa9e1 net/hns3: remove unused parameter markers
    3997b852411 net/hns3: fix HW buffer size on MTU update
    e4e0a6505d7 net/hns3: fix device capabilities for copper media type
    4371d3b12b9 common/mlx5: add DevX commands for queue counters
    6e06d42907b common/mlx5: add DevX command to query WQ
    fba807cae93 common/mlx5/linux: add glue function to query WQ
    44e87e7c102 net/pcap: fix file descriptor leak on close
    82f21305c4a net/mlx5: fix UAR allocation diagnostics messages
    1cac75b516d net/mlx5: fix hashed list size for tunnel flow groups
    cf30b35eb37 net/pcap: fix format string
    40313397da9 net/af_xdp: fix error handling during Rx queue setup
    32ae43ccb7f net/sfc: fix buffer size for flow parse
    40072bc599a app/testpmd: remove unnecessary UDP tunnel check
    7a866f25e6a net/ionic: fix completion type in lif init
    c725e11eb3b net/dpaa: fix getting link status
    d287fda7da8 net/dpaa2: fix getting link status
    e518710835e bus/dpaa: fix statistics reading
    1965f4ee959 bus/fslmc: fix random portal hangs with qbman 5.0
    58200ed66af net/mlx5: fix metadata item validation for ingress flows
    8d2066d2ec5 common/mlx5: fix DevX read output buffer size
    23b584d6cc8 net/mlx5: fix external buffer pool registration for Rx queue
    7fe1e5cdb90 net/failsafe: report minimum and maximum MTU
    9da42b8f936 net/failsafe: fix RSS hash offload reporting
    4f140c14a27 fbarray: fix log message on truncation error
    db950ecec21 vfio: fix API description
    b8bde7fa4b1 power: remove duplicated symbols from map file
    e41a908c66b test/mem: fix page size for external memory
    7f904ea0c67 vfio: fix DMA mapping granularity for IOVA as VA
    0e42f2b7ea5 vfio: do not merge contiguous areas


* Wed Aug 31 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-118
- Merging upstream branch-2.15 [RH git: f73b3f1931]
    Commit list:
    93e88f39e1 raft: Fix unnecessary periodic compactions.


* Tue Aug 09 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-117
- Merging upstream branch-2.15 [RH git: 671f431f8e]
    Commit list:
    f1a14e9600 github: Move CI to ubuntu 20.04 base image.
    176298d066 netdev-offload-dpdk: Fix vxlan vni cast-align warnings.


* Mon Aug 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-116
- Merging upstream branch-2.15 [RH git: 12c6518299]
    Commit list:
    e3909a40ae netdev-offload-tc: Disable offload of IPv6 fragments.


* Mon Aug 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-115
- Merging upstream branch-2.15 [RH git: f0a32c6c60]
    Commit list:
    173769badf system-traffic: Fix IPv4 fragmentation test sequence for check-kernel.
    3e9debe5be system-traffic: Fix incorrect neigh entry in ipv6 header modification test.
    8ec1752be7 system-traffic: Don't run IPv6 header modification test on kernels < 5.19.


* Thu Aug 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-114
- Merging upstream branch-2.15 [RH git: 61c9b3f738]
    Commit list:
    8c0a187ea5 python: Fix E275 missing whitespace after keyword.
    84b05f4397 dpif-netlink: Fix incorrect bit shift in compat mode.
    506b9a7a22 packets: Re-calculate IPv6 checksum only for first frag upon modify.


* Fri Jul 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-113
- Merging upstream branch-2.15 [RH git: d3374dc711]
    Commit list:
    f2024c9ef9 libopenvswitch.pc: Add missing libs for a static build.
    a8e6816ab2 rhel: Stop installing internal headers.


* Tue Jul 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-112
- Merging upstream branch-2.15 [RH git: 14ed491a9f]
    Commit list:
    ac90500da4 netdev-linux: Do not touch LAG members if master is not attached to OVS.
    dbfe371cdc netdev: Clear auto_classified if netdev reopened with the type specified.


* Mon Jul 25 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-111
- Merging upstream branch-2.15 [RH git: bc54a123ad]
    Commit list:
    eb3484a398 system-traffic: Properly stop dangling ping after geneve test.
    0f639878cb conntrack: Fix conntrack multiple new state.


* Thu Jul 14 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-110
- Merging upstream branch-2.15 [RH git: b75a6f236b]
    Commit list:
    8c7f759b19 tc: Fix misaligned access while creating pedit actions.


* Wed Jun 29 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-109
- Merging upstream branch-2.15 [RH git: 566da17c56]
    Commit list:
    e8c27d116d dpif-netdev: Refactor AVX512 runtime checks. (#2100393)


* Tue Jun 28 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-108
- Merging upstream branch-2.15 [RH git: 4fe2b46365]
    Commit list:
    8fa98aa7c9 ovsdb: Fix memory leak on error path in ovsdb_file_read__().
    61689d0c3b odp-util: Ignore unknown attributes in parse_key_and_mask_to_match(). (#2089331)
    3d33ff315e lldp: Fix lldp memory leak.
    ef42afed6c ipfix: Trigger revalidation if ipfix options changes.


* Mon Jun 27 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-107
- Merging upstream branch-2.15 [RH git: 9bc851aa76]
    Commit list:
    386f0af8f5 conntrack: Fix incorrect bit shift while hashing nat range.
    7ecfaf9562 odp-util: Fix unaligned access to tunnel id.
    019df265ae ofpbuf: Fix offsetting a NULL pointer in ofpbuf_reserve.
    aeac1a781a drop-stats.at: Fix frequent failures of the recursion too deep test.


* Wed Jun 15 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-106
- Merging upstream branch-2.15 [RH git: ab1d6faf99]
    Commit list:
    4c36bab380 Prepare for 2.15.6.
    b12608cc2e Set release date for 2.15.5.


* Tue Jun 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-105
- Merging upstream branch-2.15 [RH git: c904e84c3e]
    Commit list:
    3ddf43cfdd ofproto-dpif-xlate: Fix internal CT state for non-recirc traffic.
    bb5dac3ce7 classifier: Adjust segment boundary to execute prerequisite processing. (#2081773)


* Wed Jun 01 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-104
- Merging upstream branch-2.15 [RH git: 873c041417]
    Commit list:
    22ccbc1dba ofproto-dpif: Fix meter use-after-free.
    ffc10739a2 ovs-rcu: Add ovsrcu_barrier.


* Thu May 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-103
- Merging upstream branch-2.15 [RH git: d93e08b22f]
    Commit list:
    18a8b7d5d8 classifier: Make find_match_wc() prototype and definition match.
    cc783da5d9 ovsdb: raft: Fix transaction double commit due to lost leadership. (#2046340)
    292e018e27 Revert "odp-util: Always report ODP_FIT_TOO_LITTLE for IGMP."
    ecfd0b783f ofproto-dpif: Trigger revalidation if ct tp changes.


* Wed May 25 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-102
- Merging upstream branch-2.15 [RH git: 08671b1f53]
    Commit list:
    21b537549c Carefully release NBL in Windows


* Wed May 18 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-101
- Merging upstream branch-2.15 [RH git: 93d7ccfb1f]
    Commit list:
    beac697b4b tests: Properly kill ovsdb test processes.
    1f7a349be8 netdev-linux: Properly access 32-bit aligned rtnl_link_stats64 structs.


* Wed May 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-100
- Merging upstream branch-2.15 [RH git: 5fb6b64894]
    Commit list:
    3d77799747 ofproto-dpif-xlate: Remove mirror assert.
    ac49e21b6d netdev-dpdk: Fix tx drops statistic for a down netdev.


* Thu Apr 28 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-99
- vhost: fix queue number check when setting inflight FD [RH git: ba1bcead43]
    [ upstream commit 6442c329b9d2ded0f44b27d2016aaba8ba5844c5 ]
    
    In function vhost_user_set_inflight_fd, queue number in inflight
    message is used to access virtqueue. However, queue number could
    be larger than VHOST_MAX_VRING and cause write OOB as this number
    will be used to write inflight info in virtqueue structure. This
    patch checks the queue number to avoid the issue and also make
    sure virtqueues are allocated before setting inflight information.
    
    Fixes: ad0a4ae491fe ("vhost: checkout resubmit inflight information")
    
    Reported-by: Wenxiang Qian <leonwxqian@gmail.com>
    Signed-off-by: Chenbo Xia <chenbo.xia@intel.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Thu Apr 28 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-98
- vhost: fix FD leak with inflight messages [RH git: 9d20e2fe62]
    [ upstream commit af74f7db384ed149fe42b21dbd7975f8a54ef227 ]
    
    Even if unlikely, a buggy vhost-user master might attach fds to inflight
    messages. Add checks like for other types of vhost-user messages.
    
    Fixes: d87f1a1cb7b6 ("vhost: support inflight info sharing")
    
    Signed-off-by: David Marchand <david.marchand@redhat.com>
    Reviewed-by: Maxime Coquelin <maxime.coquelin@redhat.com>


* Wed Apr 27 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-97
- Merging upstream branch-2.15 [RH git: 885e0d0ad5]
    Commit list:
    cbed56773f ofproto-dpif-xlate: Clear out vlan flow fields while processing native tunnel. (#393566
    2060552)


* Tue Apr 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-96
- Merging upstream branch-2.15 [RH git: 87fde112ca]
    Commit list:
    09759f9957 ofproto-xlate: Fix crash when forwarding packet between legacy_l3 tunnels.
    dd6e5983a8 system-traffic: Fix fragment reassembly with L3 L4 protocol information.


* Thu Apr 21 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-95
- Really set RTE_ETH_MAXPORTS to 1024 [RH git: 4c53699c3e]
    Fixes: cbe02d895f52 ("Change RTE_ETH_MAXPORTS to 1024")


* Mon Apr 18 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-94
- Merging upstream branch-2.15 [RH git: c55ba17247]
    Commit list:
    3da1b0c456 cirrus: Update FreeBSD versions.


* Fri Apr 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-93
- Merging upstream branch-2.15 [RH git: c8842bbbf9]
    Commit list:
    27a2daad0e Prepare for 2.15.5.
    c281f01dd3 Set release date for 2.15.4.


* Fri Apr 08 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-92
- Merging upstream branch-2.15 [RH git: 74dde447f6]
    Commit list:
    d848639d27 NEWS: Highlight libopenvswitch API change caused by UB fixes.


* Wed Apr 06 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-91
- Merging upstream branch-2.15 [RH git: 09b0ffda32]
    Commit list:
    3719bdafc4 netdev-offload-tc: Check for ct_state flag combinations that are not offloadable.


* Tue Apr 05 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-90
- Merging upstream branch-2.15 [RH git: 9e3e8cde3c]
    Commit list:
    80b57ee01f dpif-netdev: Fix dp_netdev_get_pmd() function getting correct core_id.
    c1bbb1ec6d ofproto-dpif-xlate: Fix NULL pointer dereference in xlate_normal().


* Wed Mar 30 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-89
- Merging upstream branch-2.15 [RH git: c42b42c1dc]
    Commit list:
    beaea86825 sparse: bump recommended version and include headers.
    4744b939c1 rculist: use multi-variable helpers for loop macros.
    ab4f0e6fd3 hindex: use multi-variable iterators.
    b1c7d8a278 cmap: use multi-variable iterators.
    fa11ec93e1 hmap: implement UB-safe hmap pop iterator.
    5f70b45cd7 hmap: use multi-variable helpers for hmap loops.
    2cbb77724e list: use multi-variable helpers for list loops.
    e345d7bf2a util: add helpers to overload SAFE macro.
    842d7f6814 util: add safe multi-variable iterators.
    f1625aa4d3 util: add multi-variable loop iterator macros.


* Wed Mar 30 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-88
- Merging upstream branch-2.15 [RH git: a03b5c62e4]
    Commit list:
    0a3867a9a9 ovsdb: raft: Fix inability to read the database with DNS host names. (#2055097)


* Mon Mar 28 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-87
- Merging upstream branch-2.15 [RH git: bba298f05e]
    Commit list:
    572ea8e0ef system-traffic.at: Fix flaky DNAT load balancing test.


* Wed Mar 23 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-86
- Merging upstream branch-2.15 [RH git: 68ea3ca4b4]
    Commit list:
    25dab05c39 tests: Fix incorrect usage of OVS_WAIT_UNTIL.


* Mon Mar 21 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-85
- Merging upstream branch-2.15 [RH git: 7b1d494b1f]
    Commit list:
    c804df6e11 odp-util: Fix output for tc to be equal to kernel.
    92207b062a netdev-offload-tc: Fix IP and port ranges in flower returns.
    743974a961 netdev-offload-tc: Always include conntrack information to tc.
    0ea2fa78e3 netdev-offload-tc: Check for valid netdev ifindex in flow_put.
    e832fa9b12 netdev-offload-tc: Set the correct VLAN_VID and VLAN_PCP masks.
    7dace029e8 netdev-offload-tc: Add debug logs on tc rule verify failures.
    56ee5f7070 tc: Keep header rewrite actions order.


* Fri Mar 18 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-84
- Merging upstream branch-2.15 [RH git: 137641442f]
    Commit list:
    fd8b2511db ofproto-dpif-xlate: Avoid successive ct_clear datapath actions.


* Mon Mar 14 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-83
- Merging upstream branch-2.15 [RH git: d2abb6b2f3]
    Commit list:
    45e10d84d7 dpdk: Use DPDK 20.11.4 release


* Fri Mar 11 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-82
- Merging upstream branch-2.15 [RH git: 7bb43bfb9f]
    Commit list:
    deeec60597 ofp-prop: Silence the 'may be uninitialized' warning.
    fa26f1f847 ovsdb-cluster.at: Avoid test failures due to different hashing.


* Mon Mar 07 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-81
- Merging upstream branch-2.15 [RH git: a735607890]
    Commit list:
    8a58897b56 ofproto: Use xlate map for uuid lookups.
    c091911e13 ofproto: Add refcount to ofproto to fix ofproto use-after-free.


* Sat Mar 05 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-80
- Merging upstream branch-2.15 [RH git: 729a55e204]
    Commit list:
    08d77484f6 ofproto-dpif: Trigger revalidation when ipfix config set.
    bc3b88c8ad system-tso: Skip encap tests when userspace TSO is enabled.


* Fri Mar 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-79
- Merging upstream branch-2.15 [RH git: 82cbd329f0]
    Commit list:
    e05105f1e6 tc: Fix stats byte count on fragmented packets.
    81aa8c8073 compat: Add gen_stats include to define tc hw stats.


* Tue Mar 01 2022 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-78
- Change RTE_ETH_MAXPORTS to 1024 [RH git: cbe02d895f] (#2048601)
    Resolves: #2048601


* Sat Feb 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-77
- Merging upstream branch-2.15 [RH git: 50c394233c]
    Commit list:
    b6007add57 ovsdb: raft: Fix inability to join the cluster after interrupted attempt. (#2033514)
    dce48bb003 reconnect: Fix broken inactivity probe if there is no other reason to wake up.


* Thu Feb 24 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-76
- Merging upstream branch-2.15 [RH git: 9265101135]
    Commit list:
    115f1543b2 datapath-windows: Fix NXM_OF_IP_TOS issue


* Wed Feb 16 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-75
- Merging upstream branch-2.15 [RH git: a01913de4d]
    Commit list:
    8a60afaa00 ovsdb-idl: Fix use-after-free when destroying an IDL loop.


* Tue Feb 15 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-74
- Merging upstream branch-2.15 [RH git: 84306060e6]
    Commit list:
    9e2af615c1 dpif-netdev-dpcls: Make subtable reprobe thread-safe.


* Tue Feb 15 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-73
- Merging upstream branch-2.15 [RH git: 0b62621839]
    Commit list:
    7691fbe77b dp-packet: Ensure packet base is always non-NULL.
    deb59ba9af bfd: lldp: stp: Fix misaligned packet field access.
    2b2371b3c3 ovsdb-idlc: Avoid accessing member within NULL idl index cursors.
    193c79ca40 stopwatch: Fix buffer underflow when computing percentiles.


* Wed Feb 09 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-72
- Merging upstream branch-2.15 [RH git: e478bef7a4]
    Commit list:
    1c050d932b ofproto: Fix ipfix not always sampling on egress. (#2016346)


* Wed Feb 09 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-71
- Merging upstream branch-2.15 [RH git: 87783c67a6]
    Commit list:
    bfc8902e3f tc: Fix incorrect TC rule for decap+encap datapath flow.


* Fri Feb 04 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-70
- Merging upstream branch-2.15 [RH git: ed4cf202b5]
    Commit list:
    38970bf78b odp-util: Fix tunnel key attr for GTP-U.
    57456cec36 ovsdb-idl: Only process successful txn in ovsdb_idl_loop_run.


* Wed Feb 02 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-69
- Merging upstream branch-2.15 [RH git: ffd65899bd]
    Commit list:
    01f8e5199d ofproto-dpif-upcall: Fix n_revalidators on upcall show.


* Mon Jan 31 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-68
- Merging upstream branch-2.15 [RH git: df7561a258]
    Commit list:
    02dd680dc5 ovsdb-idl: ovsdb_idl_loop_destroy must also destroy the committing txn.
    b664877079 ovsdb-cs: Clear last_id on reconnect if condition changes in-flight.
    dec99de837 ofp-flow: Skip flow reply if it exceeds the maximum message size.
    2a92aac033 ovsdb-cs: Fix ignoring of the last id from the initial monitor reply. (#2044624)


* Wed Jan 26 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-67
- Merging upstream branch-2.15 [RH git: 0ec5c70e5a]
    Commit list:
    ed5a1bc688 ofproto-dpif: Fix issue with non-reversible actions on a patch ports.


* Tue Jan 25 2022 Eelco Chaudron <echaudro@redhat.com> - 2.15.0-66
- downstream: Enable usdt probes in build [RH git: 3e2ddcc2da]
    Fixes: BZ1840877


* Tue Jan 25 2022 Eelco Chaudron <echaudro@redhat.com> - 2.15.0-65
- utilities: Add netlink flow operation USDT probes and upcall_cost script. [RH git: 1ef4073913]
    This patch adds a series of NetLink flow operation USDT probes.
    These probes are in turn used in the upcall_cost Python script,
    which in addition of some kernel tracepoints, give an insight into
    the time spent on processing upcall.
    
    Signed-off-by: Eelco Chaudron <echaudro@redhat.com>
    Acked-by: Paolo Valerio <pvalerio@redhat.com>
    Signed-off-by: Ilya Maximets <i.maximets@ovn.org>


* Tue Jan 25 2022 Eelco Chaudron <echaudro@redhat.com> - 2.15.0-64
- utilities: Add upcall USDT probe and associated script. [RH git: f581b3a82c]
    Added the dpif_recv:recv_upcall USDT probe, which is used by the
    included upcall_monitor.py script. This script receives all upcall
    packets sent by the kernel to ovs-vswitchd. By default, it will
    show all  upcall events, which looks something like this:
    
     TIME               CPU  COMM      PID      DPIF_NAME          TYPE PKT_LEN FLOW_KEY_LEN
     5952147.003848809  2    handler4  1381158  system@ovs-system  0    98      132
     5952147.003879643  2    handler4  1381158  system@ovs-system  0    70      160
     5952147.003914924  2    handler4  1381158  system@ovs-system  0    98      152
    
    It can also dump the packet and NetLink content, and if required,
    the packets can also be written to a pcap file.
    
    Signed-off-by: Eelco Chaudron <echaudro@redhat.com>
    Acked-by: Paolo Valerio <pvalerio@redhat.com>
    Signed-off-by: Ilya Maximets <i.maximets@ovn.org>


* Tue Jan 25 2022 Eelco Chaudron <echaudro@redhat.com> - 2.15.0-63
- Documentation: Add USDT documentation and bpftrace example. [RH git: 2a54ac2f9f]
    Add the USDT documentation and a bpftrace example using the
    bridge run USDT probes.
    
    Signed-off-by: Eelco Chaudron <echaudro@redhat.com>
    Acked-by: Paolo Valerio <pvalerio@redhat.com>
    Signed-off-by: Ilya Maximets <i.maximets@ovn.org>


* Tue Jan 25 2022 Eelco Chaudron <echaudro@redhat.com> - 2.15.0-62
- openvswitch: Define the OVS_STATIC_TRACE() macro. [RH git: fa1e850486]
    This patch defines the OVS_STATIC_TRACE() macro, and as an
    example, adds two of them in the bridge run loop.
    
    Signed-off-by: Eelco Chaudron <echaudro@redhat.com>
    Acked-by: Paolo Valerio <pvalerio@redhat.com>
    Signed-off-by: Ilya Maximets <i.maximets@ovn.org>


* Tue Jan 25 2022 Eelco Chaudron <echaudro@redhat.com> - 2.15.0-61
- configure: Add --enable-usdt-probes option to enable USDT probes. [RH git: e1e982a7c1]
    Allow inclusion of User Statically Defined Trace (USDT) probes
    in the OVS binaries using the --enable-usdt-probes option to the
    ./configure script.
    
    Signed-off-by: Eelco Chaudron <echaudro@redhat.com>
    Acked-by: Paolo Valerio <pvalerio@redhat.com>
    Signed-off-by: Ilya Maximets <i.maximets@ovn.org>


* Fri Jan 21 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-60
- Merging upstream branch-2.15 [RH git: a70244a272]
    Commit list:
    e59194b606 ovs-monitor-ipsec: Fix generated strongSwan ipsec.conf for IPv6.


* Thu Jan 20 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-59
- Merging upstream branch-2.15 [RH git: d17382a24e]
    Commit list:
    2632aeb374 datapath-windows: Pickup Ct tuple as CT lookup key in function OvsCtSetupLookupCtx


* Tue Jan 18 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-58
- Merging upstream branch-2.15 [RH git: 14826e19b9]
    Commit list:
    7f978ee372 Documentation: Fix Rx/Tx queue configuration section.


* Mon Jan 17 2022 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-57
- Merging upstream branch-2.15 [RH git: 228a38c3dc]
    Commit list:
    a7dc6af0fc ofproto-dpif: Fix memory leak in dpif/show-dp-features appctl.


* Sat Dec 18 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-56
- Merging upstream branch-2.15 [RH git: 9504acc03d]
    Commit list:
    31288dc725 Prepare for 2.15.4.
    e4d2df62e6 Set release date for 2.15.3.
    b8baa11416 python: Add cooperative_yield() API method to Idl.
    7834abc669 ofproto-dpif-xlate: Snoop ingress packets and update neigh cache if needed.
    833c02daab tnl-neigh-cache: Do not refresh the entry while revalidating.
    e2182eca88 tnl-neigh-cache: Include expected array sizes in prototypes.
    566fe43721 tnl-neigh-cache: Read/write expires atomically.


* Thu Dec 09 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-55
- Merging upstream branch-2.15 [RH git: a1abf356d3]
    Commit list:
    d477f60008 compat: handle NF_REPEAT error on nf_conntrack_in.


* Mon Dec 06 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-54
- Merging upstream branch-2.15 [RH git: d4f13fd840]
    Commit list:
    0590e88387 flow: Consider dataofs when parsing TCP packets.
    7266042d84 tests/flowgen: Fix packet data endianness.
    d2e0632dbe ofproto: Fix resource usage explosion due to removal of large number of flows.
    0a7e66e37f ofproto: Fix resource usage explosion while processing bundled FLOW_MOD.
    68466efed9 tests/flowgen: Fix length field of 802.2 data link header.
    2a2185f9e6 ovs-lib: Backup and remove existing DB when joining cluster.
    fcbc29c6f0 docs/dpdk: Fix install doc.
    a5d97d4202 ovs-save: Save igmp flows in ofp_parse syntax.
    1cbd1f0f56 faq: Update OVS/DPDK version table for OVS 2.13/2.14.


* Thu Nov 18 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-53
- Merging upstream branch-2.15 [RH git: 9221a2233d]
    Commit list:
    01bc910e57 ofproto-dpif-xlate: Fix check_pkt_larger incomplete translation.


* Mon Nov 15 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-52
- Merging upstream branch-2.15 [RH git: 001ae577c6]
    Commit list:
    08a270dda1 datapath-windows: Reset flow key after Ipv4 fragments are reassembled


* Thu Oct 28 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-51
- Merging upstream branch-2.15 [RH git: a134a530c9]
    Commit list:
    eca2d50d40 datapath-windows:Reset PseudoChecksum value only for TX direction offload case


* Wed Oct 27 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-50
- Merging upstream branch-2.15 [RH git: 16dad85706]
    Commit list:
    031cf67e09 netdev-offload-tc: Verify the flower rule installed.


* Wed Oct 27 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-49
- Merging upstream branch-2.15 [RH git: 2502ca29b0]
    Commit list:
    952e851506 ci: Make linux-prepare trust system installs.


* Mon Oct 25 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-48
- Merging upstream branch-2.15 [RH git: 7cf784736e]
    Commit list:
    2cf63851a5 Prepare for 2.15.3.
    63f9a7c5d8 Set release date for 2.15.2.


* Tue Oct 19 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-47
- Merging upstream branch-2.15 [RH git: 01110b9088]
    Commit list:
    b7d9c491ec datapath-windows: add layers when adding the deferred actions


* Thu Oct 14 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-46
- Merging upstream branch-2.15 [RH git: f8619036c9]
    Commit list:
    3f718857e7 ofproto-dpif-xlate: Fix zone set from non-frozen-metadata fields.


* Wed Oct 13 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-45
- Merging upstream branch-2.15 [RH git: e273e307d1]
    Commit list:
    ea2ca0af16 dpif-netdev: Fix use-after-free on PACKET_OUT of IP fragments.
    9f964354e3 tunnel-push-pop.at: Mask source port in tunnel header.


* Tue Oct 12 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-44
- Merging upstream branch-2.15 [RH git: 3050e5222d]
    Commit list:
    58397f222b dpdk-stub: Change the ERR log to DBG.
    2a963fc314 python: idl: Avoid sending transactions when the DB is not synced up.


* Tue Oct 12 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-43
- Merging upstream branch-2.15 [RH git: 09e3ab3630]
    Commit list:
    9efa2ea619 ipf: release unhandled packets from the batch


* Thu Sep 30 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-42
- Merging upstream branch-2.15 [RH git: 2a86017f3f]
    Commit list:
    f8274b78c3 datapath-windows:adjust Offset when processing packet in POP_VLAN action


* Mon Sep 27 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-41
- Merging upstream branch-2.15 [RH git: 8f2e30f011]
    Commit list:
    a2f860aa2e cirrus: Reduce memory requirements for FreeBSD VMs.


* Thu Sep 23 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-40
- redhat: use hugetlbfs group for /var/log/openvswitch when dpdk is enabled [RH git: 5ccf239b51] (#2007290)
    Resolves: #2007290


* Thu Sep 16 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-39
- Merging upstream branch-2.15 [RH git: c6bdfa8cc1]
    Commit list:
    7788f15798 netdev-linux: Fix a null pointer dereference in netdev_linux_notify_sock().
    dd32deba6e pcap-file: Fix memory leak in ovs_pcap_open().
    9f2f66c8ea odp-util: Fix a null pointer dereference in odp_flow_format().
    02b0c265c4 odp-util: Fix a null pointer dereference in odp_nsh_key_from_attr__().
    031eff4563 netdev-dpdk: Fix RSS configuration for virtio.
    09cd9570d2 ipf: Fix only nat the first fragment in the reass process.


* Wed Sep 15 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-38
- ofproto-dpif-xlate: Avoid successive ct_clear datapath actions. [RH git: f9a9ac7608] (#1941027)
    Due to flow lookup optimizations, especially in the resubmit/clone cases,
    we might end up with multiple ct_clear actions, which are not necessary.
    
    This patch only adds the ct_clear action to the datapath if any ct state
    is tracked.
    
    Resolves: #1941027
    
    Signed-off-by: Eelco Chaudron <echaudro@redhat.com>
    Acked-by: Timothy Redaelli <tredaelli@redhat.com>
    Signed-off-by: Ilya Maximets <i.maximets@ovn.org>
    (cherry picked from commit 355fef6f2ccbcf78797b938421cb4cef9b59af13)


* Wed Sep 08 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-37
- Merging upstream branch-2.15 [RH git: b36eb7e529]
    Commit list:
    ef8ca3e190 dpif-netdev: Fix crash when PACKET_OUT is metered.


* Tue Aug 17 2021 Michael Santana <msantana@redhat.com> - 2.15.0-36
- Migrate openvswitch to gitlab [RH git: 93147e2cda]
    Signed-off-by: Michael Santana <msantana@redhat.com>


* Mon Aug 16 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-35
- Merging upstream branch-2.15 [RH git: 11bcf52d03]
    Commit list:
    d3ff41d609 tc: Set action flags for tunnel_key release.
    079a4de723 netlink-socket: Replace error with txn->error when logging nacked transactions.
    f8cc5aa35c dynamic-string: Fix a crash in ds_clone().


* Mon Aug 16 2021 Michael Santana <msantana@redhat.com> - 2.15.0-34
- pkgtool: Swap bugzilla id and RH git [RH git: c2e6243d60]
    Having the bugzilla ID not at the end of the line breakes another script
    that parses for said ID. This patch fixes that by putting the ID next to
    the new line
    
    Fixes: f6b2db4dd33e ("Make changelog in spec file more informative")
    Signed-off-by: Michael Santana <msantana@redhat.com>


* Mon Aug 16 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-33
- Merging upstream branch-2.15 [RH git: 08b4ccb1c4]
    Commit list:
    64d1bba919 dpif-netdev: fix memory leak in dpcls subtable set command


* Tue Aug 03 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-32
- Merging upstream branch-2.15 [RH git: 2cc833ce5b]
    Commit list:
    90b219275d dpif-netdev: Do not flush PMD offloads on reload.


* Mon Aug 02 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-31
- Merging upstream branch-2.15 [RH git: 88fb0bba8a]
    Commit list:
    b29b04f85f dpif-netdev: Fix offloads of modified flows.
    1d0b89ea7b dpif-netdev: Fix flow modification after failure.


* Mon Jul 26 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-30
- Merging upstream branch-2.15 [RH git: a76a4dfca6]
    Commit list:
    8d84a4b166 netdev-offload-dpdk: Fix IPv6 rewrite cast-align warning.
    f3f7849cbb daemon-unix: Fix leak of a fork error message.


* Fri Jul 23 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-29
- Merging upstream branch-2.15 [RH git: 60c8b2a15b]
    Commit list:
    8aa0f03747 ovsdb-cs: Perform forced reconnects without a backoff.


* Wed Jul 21 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-28
- Merging upstream branch-2.15 [RH git: 48a90081e8]
    Commit list:
    ee4e034dc9 datapath-windows:Correct checksum for DNAT action


* Sat Jul 17 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-27
- Merging upstream branch-2.15 [RH git: abdd952536]
    Commit list:
    72132a9403 bond: Fix broken rebalancing after link state changes.
    aa84cfe25d dpif-netlink: Fix report_loss() message.
    aec05f7cd1 ovsdb-server: Fix memleak when failing to read storage.
    05bdf11fc3 conntrack: Init hash basis first at creation.
    94e3b9d9ce netdev-linux: Ignore TSO packets when TSO is not enabled for userspace.
    842bfb899f conntrack: Handle already natted packets.
    ab873c1afe conntrack: Document all-zero IP SNAT behavior and add a test case.
    86d6a9ee14 python: Fix Idl.run change_seqno update.
    1ba0c83655 bridge: Use correct (legacy) role names in database.
    7e5293ea5a Prepare for 2.15.2.
    b855bbc326 Set release date for 2.15.1.
    007a4f48fe dpif-netdev: Apply subtable-lookup-prio-set on any datapath.
    c93358a563 netlink: removed incorrect optimization
    31626579fa ovs-actions.xml: Add missing bracket.
    30596ec278 netdev-offload-tc: Use nl_msg_put_flag for OVS_TUNNEL_KEY_ATTR_CSUM.
    728980291a conntrack: Increment coverage counter for all bad checksum cases.


* Wed Jun 30 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-26
- Use 10 characters of hash to generate the changelog [RH git: d89d9cd0f1]
    This is needed to avoid that the history changes since the default
    changes from time to time


* Wed Jun 30 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-25
- Merging 881d71ea22e datapath-windows: Specify external include .. [RH git: 8ad5538601]
    Commit list:
    881d71ea22e datapath-windows: Specify external include paths
    934668c295e Remove Python 2 leftovers.
    aaa59670556 ipf: Fix a use-after-free error, and remove the 'do_not_steal' flag.


* Fri Jun 11 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-24
- Merging upstream branch-2.15 [RH git: 78ba3622d9]
    Commit list:
    bc0aa785a8 ovsdb-idl: Fix the database update signaling if it has never been connected.
    559426d2b0 ofproto: Fix potential NULL dereference in ofproto_ct_*_zone_timeout_policy().
    f31070e27e ofproto: Fix potential NULL dereference in ofproto_get_datapath_cap().


* Thu May 27 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-23
- Merging upstream branch-2.15 [RH git: ba3ba16d42]
    Commit list:
    8995d53112 dpif-netlink: Fix send of uninitialized memory in ct limit requests.
    0c056891c2 ofproto-dpif: Fix use of uninitialized attributes of timeout policy.
    121a67cad3 netdev-linux: Fix use of uninitialized LAG master name.
    5f27ff1cfa ofp_actions: Fix set_mpls_tc formatting.


* Wed May 19 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-22
- Merging upstream branch-2.15 [RH git: 8b6b82c2ed]
    Commit list:
    e87adce83c dpif-netdev: Remove meter rate from the bucket size calculation.


* Sat May 15 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-21
- Merging upstream branch-2.15 [RH git: c7b9daa243]
    Commit list:
    a3ee3258e2 ovs-ofctl: Fix coredump when using "add-groups" command.


* Fri May 14 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-20
- Merging upstream branch-2.15 [RH git: 69559c9283]
    Commit list:
    c5d2a62750 raft: Transfer leadership before creating snapshots.


* Fri May 14 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-19
- Merging upstream branch-2.15 [RH git: 6aa50cbb89]
    Commit list:
    553d523929 ovsdb-cs: Consider all tables when computing expected cond seqno.
    8d0aebcc49 dpdk: Use DPDK 20.11.1 release.


* Wed May 12 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-18
- Merge tag 'b6167fabb202faa025946348f514e369dba5853b' into fast-datapath-rhel-8 [RH git: 1cdc5555f9]
    dpdk-20.11.1


* Tue May 11 2021 Open vSwitch CI <ovs-ci@redhat.com> - 2.15.0-17
- Merging upstream branch-2.15 [RH git: 120e2a5d87]
    Commit list:
    21452722b7 github: Fix up malformed /etc/hosts.
    90d1984b99 doc: automake: Add support for sphinx 4.0.
    38a8bed703 cirrus: Look up existing versions of python dependencies.


* Mon May 10 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-16
- Merging upstream branch-2.15 [RH git: dbd5501f48]
    Commit list:
    255c38c745 ofp-group: Use big-enough buffer in ofputil_format_group().


* Wed Apr 21 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-15
- Merging upstream branch-2.15 [RH git: 85f5aecb83]
    Commit list:
    f2c0744d2f ofproto/ofproto-dpif-sflow: Check sflow agent in case of race


* Tue Apr 20 2021 Aaron Conole <aconole@redhat.com> - 2.15.0-14
- Merging ct_state_fix [RH git: f847e4fac1]
    Commit list:
    09a2081067 netdev-offload-tc: Add support for ct_state flag rel.
    423048a34f netdev-offload-tc: Add support for ct_state flags inv and rpl


* Tue Apr 20 2021 Aaron Conole <aconole@redhat.com> - 2.15.0-13
- ab157ef34d dpif: Fix use of uninitialized execute hash. b1fded0208 odp-util: Fix use of uninitialized erspan metadata. f473ee5689 dpif-netlink: Fix using uninitialized info.tc_modify_flow_deleted in out label. 2721606bd4 netdev-offload-tc: Probe for support for any of the ct_state flags. 091bc48d9c compat: Add ct_state flags definitions. [RH git: e4336ed96c]


* Tue Apr 20 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-12
- Fix typo in rh-mock-srpm [RH git: 85631264db]
    Thanks fbl for reporting


* Wed Apr 14 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-11
- Merging upstream branch-2.15 [RH git: 71c33052b9]
    Commit list:
    1307e90e3f Add test cases for ingress_policing parameters
    d184c6ce67 netdev-linux: correct unit of burst parameter


* Wed Apr 07 2021 Michael Santana <msantana@redhat.com> - 2.15.0-10
- Make changelog in spec file more informative [RH git: f6b2db4dd3]
    This is done by adding the body of the commit message to the changelong.
    The body is indented and has extra spacing separating each entry in the
    changelog to make each one more discernible since now they could be
    longer
    
    Signed-off-by: Michael Santana <msantana@redhat.com>


* Thu Apr 01 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-9
- Merging upstream branch-2.15 [RH git: 504b67ec8d]
    Commit list:
    cab998e500 ipsec: Fix IPv6 default route support for Libreswan.


* Thu Apr 01 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-8
- Merging upstream branch-2.15 [RH git: 147a0970be]
    Commit list:
    b9ab7827ec ovsdb-idl: Mark arc sources as updated when destination is deleted.
    c82d2e3fbc ovsdb-idl: Preserve references for deleted rows.
    9a24ecbc2a ovsdb-idl.at: Make test outputs more predictable.


* Wed Mar 31 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-7
- Merging upstream branch-2.15 [RH git: cbb083630e]
    Commit list:
    8d71feb1b8 ovs-ofctl: Fix segfault due to bad meter n_bands.


* Wed Mar 31 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-6
- Merging upstream branch-2.15 [RH git: 221cf613d7]
    Commit list:
    3a716b1d9c dpif-netdev: Refactor and fix the buckets calculation.
    73ece9c87b dpif-netdev: Fix the meter buckets overflow.


* Mon Mar 22 2021 Kevin Traynor <ktraynor@redhat.com> - 2.15.0-5
- dpif-netdev: Allow PMD auto load balance with cross-numa. [RH git: 47e2824210] (#1941673)
    commit ec68a877db5bbfba49ddeb9929479c033420ea6b
    Author: Kevin Traynor <ktraynor@redhat.com>
    Date:   Thu Mar 18 11:34:04 2021 +0000
    
        dpif-netdev: Allow PMD auto load balance with cross-numa.
    
        Previously auto load balance did not trigger a reassignment when
        there was any cross-numa polling as an rxq could be polled from a
        different numa after reassign and it could impact estimates.
    
        In the case where there is only one numa with pmds available, the
        same numa will always poll before and after reassignment, so estimates
        are valid. Allow PMD auto load balance to trigger a reassignment in
        this case.
    
        Acked-by: Eelco Chaudron <echaudro@redhat.com>
        Acked-by: David Marchand <david.marchand@redhat.com>
        Tested-by: Sunil Pai G <sunil.pai.g@intel.com>
        Acked-by: Flavio Leitner <fbl@sysclose.org>
        Signed-off-by: Kevin Traynor <ktraynor@redhat.com>
        Signed-off-by: Ilya Maximets <i.maximets@ovn.org>
    
    Reported-at: https://bugzilla.redhat.com/show_bug.cgi?id=1941673
    Conflicts: Commit backported from upstream master branch. Commit not
    present on upstream branch-2.15. Removed NEWS file update as could cause
    future merge conflicts.


* Fri Mar 19 2021 Kevin Traynor <ktraynor@redhat.com> - 2.15.0-4
- redhat: Update docs for test builds [RH git: 7620c95a37]


* Tue Mar 16 2021 Open vSwitch CI <ovs-team@redhat.com> - 2.15.0-3
- Merging upstream branch-2.15 [RH git: c4fc969d7e]
    Commit list:
    d5dc16670e python: Send notifications after the transaction ends.
    556e65e179 ovs-ctl: Allow recording hostname separately.
    3982aee455 dpif-netdev: Fix crash when add dp flow without in_port field.
    02096f1b37 Documentation: Fix DPDK qos example.
    8f1dda3164 raft: Report disconnected in cluster/status if candidate retries election.
    79e9749daa raft: Reintroduce jsonrpc inactivity probes.
    2e84a4adb1 ovsdb-cs: Fix use-after-free for the request id.
    d2c311dce8 connmgr: Check nullptr inside ofmonitor_report().
    7307af6908 ovsdb-client: Fix needs-conversion when SERVER is explicitly specified.
    2a7a635718 windows, tests: Modify service test.
    9b48549c68 netdev-linux: Fix indentation.
    861a9f3b4d ofproto-dpif-upcall: Fix ukey leak on udpif destroy.
    339044c3cc ci: Use parallel build for distcheck.
    38744b1bcb ofp-actions: Fix use-after-free while decoding RAW_ENCAP.
    33abe6c052 Prepare for 2.15.1.


* Tue Feb 16 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-2
- build with ipsec support by default [RH git: 105482aee7]


* Mon Feb 15 2021 Timothy Redaelli <tredaelli@redhat.com> - 2.15.0-1
- Use official 2.15.0 tarball [RH git: 9e107c6359]


